/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_zh_CN.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_zh_CN.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_zh_CN(DocIntf *doc)
{
  doc->setHeader(
              "此文件描述了项目文档系统 Doxygen (www.doxygen.org) 所使用的设置。\n"
              "\n"
              "双井号(##)后面的所有文本都被视为注释，并放置在 其前面的标签之前。\n"
              "\n"
              "单井号(#)后面的所有文本都被视为注释，并将被忽略。 格式如下：\n"
              "TAG = value [value, ...]\n"
              "对于列表，也可以使用以下方式追加项目：\n"
              "TAG += value [value, ...]\n"
              "包含空格的值应放在引号(\" \")之间。\n"
              "\n"
              "注意：\n"
              "\n"
              "使用 Doxygen 将使用的配置文件与模板配置文件进行比较：\n"
              "doxygen -x [configFile]\n"
              "使用 Doxygen 将使用的配置文件与模板配置文件进行比较， 且不替换环境变量或 CMake 类型的替换变量：\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "此标签指定配置文件中所有后续字符使用的编码。默认值为 UTF-8，这也是此标签首次出现之前所有文本使用的编码。Doxygen 使用 libiconv （或\n"
              "libc 中内置的 iconv）进行转码。有关可能的编码列表，请参阅 https://www.gnu.org/software/libiconv/。\n"
              "默认值为： UTF-8。"
          );
  doc->add(
              "PROJECT_NAME",
              "PROJECT_NAME 标签是一个单词（除非使用\n"
              "Doxywizard，否则为用双引号括起来的一系列单词），用于标识生成文档的项目。此名称用于大多数生成页面的标题和其他一些地方。\n"
              "默认值为： My Project。"
          );
  doc->add(
              "PROJECT_NUMBER",
              "PROJECT_NUMBER 标签可用于输入项目或修订号。这对于归档生成的文档或使用版本控制系统时很有用。"
          );
  doc->add(
              "PROJECT_BRIEF",
              "使用 PROJECT_BRIEF 标签可以为项目提供可选的一行描述，该描述显示在每个页面的顶部，应该给查看者一个关于项目目的的快速概念。保持描述简短。"
          );
  doc->add(
              "PROJECT_LOGO",
              "使用 PROJECT_LOGO 标签可以指定包含在文档中的徽标或图标。徽标的最大高度不应超过 55 像素，最大宽度不应超过 200 像素。Doxygen\n"
              "会将徽标复制到输出目录。"
          );
  doc->add(
              "PROJECT_ICON",
              "使用 PROJECT_ICON 标签可以指定显示 HTML 文档时包含在选项卡中的图标。Doxygen 会将徽标复制到输出目录。"
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "OUTPUT_DIRECTORY 标签用于指定生成文档的（相对或绝对）路径。如果输入相对路径，它将相对于 Doxygen\n"
              "启动的位置。如果留空，则使用当前目录。"
          );
  doc->add(
              "CREATE_SUBDIRS",
              "如果 CREATE_SUBDIRS 标签设置为 YES ，Doxygen 将在每个输出格式的输出目录下创建最多 4096 个子目录（2\n"
              "个级别），并将生成的文件分发到这些目录中。当向 Doxygen\n"
              "提供大量源文件时，启用此选项很有用，否则将所有生成的文件放在同一目录中可能会导致文件系统的性能问题。调整 CREATE_SUBDIRS_LEVEL\n"
              "以控制子目录的数量。\n"
              "默认值为： NO。"
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "控制当 CREATE_SUBDIRS 标签设置为 YES 时创建的子目录数量。级别 0 表示 16 个目录，每个级别增量使目录数量翻倍，在级别 8 时结果为\n"
              "4096 个目录，这是默认值也是最大值。子目录分为 2 个级别组织，第一级始终有固定的 16 个目录。\n"
              "最小值：0，最大值：8，默认值：8。\n"
              "此标签要求标签 CREATE_SUBDIRS 设置为YES。"
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "如果 ALLOW_UNICODE_NAMES 标签设置为 YES ，Doxygen 将允许非 ASCII 字符出现在生成文件的名称中。如果设置为 NO ，非\n"
              "ASCII 字符将被转义，例如 _xE3_x81_x84 将用于 Unicode U+3044。\n"
              "默认值为： NO。"
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "OUTPUT_LANGUAGE 标签用于指定 Doxygen 生成的所有文档使用的语言。Doxygen 将使用此信息以正确的语言生成所有常量输出。\n"
              "可能的值有：Afrikaans, Arabic, Armenian, Brazilian, Bulgarian, Catalan, Chinese,\n"
              "Chinese-Traditional, Croatian, Czech, Danish, Dutch, English （美国）, Esperanto,\n"
              "Farsi （波斯语）, Finnish, French, German, Greek, Hindi, Hungarian, Indonesian,\n"
              "Italian, Japanese, Japanese-en （日语带英语消息）, Korean, Korean-en （韩语带英语消息）,\n"
              "Latvian, Lithuanian, Macedonian, Norwegian, Persian （波斯语）, Polish, Portuguese,\n"
              "Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene, Spanish,\n"
              "Swedish, Turkish, Ukrainian和Vietnamese.\n"
              "默认值为： English。"
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "如果 BRIEF_MEMBER_DESC 标签设置为 YES ，Doxygen 将在文件和类文档中包含简要成员描述（类似于 Javadoc ）。设置为 NO\n"
              "以禁用此功能。\n"
              "默认值为： YES。"
          );
  doc->add(
              "REPEAT_BRIEF",
              "如果 REPEAT_BRIEF 标签设置为 YES ，Doxygen 将在详细描述之前添加成员或函数的简要描述。\n"
              "\n"
              "注意：如果 HIDE_UNDOC_MEMBERS 和 BRIEF_MEMBER_DESC 都设置为 NO ，简要描述将被完全抑制。\n"
              "默认值为： YES。"
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "此标签实现了一个准智能简要描述缩写器，用于形成各种列表中的文本。此列表中的每个字符串，如果作为简要描述的前导文本找到，将从文本中剥离，处理整个列表后的结果用\n"
              "作注释文本。否则，简要描述按原样使用。如果留空，则使用以下值（$name 自动替换为实体名称）：The $name class, The $name\n"
              "widget, The $name file, is, provides, specifies, contains, represents, a,\n"
              "an和the."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "如果 ALWAYS_DETAILED_SEC 和 REPEAT_BRIEF 标签都设置为 YES ，那么即使只有简要描述，Doxygen 也会生成详细部分。\n"
              "默认值为： NO。"
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "如果 INLINE_INHERITED_MEMB 标签设置为 YES ，Doxygen\n"
              "将在类的文档中显示所有继承的成员，就像这些成员是普通类成员一样。基类的构造函数、析构函数和赋值运算符将不会显示。\n"
              "默认值为： NO。"
          );
  doc->add(
              "FULL_PATH_NAMES",
              "如果 FULL_PATH_NAMES 标签设置为 YES ，Doxygen 将在文件列表和头文件中添加完整路径前缀。如果设置为 NO\n"
              "，将使用使文件名唯一的最短路径。\n"
              "默认值为： YES。"
          );
  doc->add(
              "STRIP_FROM_PATH",
              "STRIP_FROM_PATH\n"
              "标签可用于剥离用户定义的部分路径。只有当指定的字符串之一与路径的左侧部分匹配时，才会进行剥离。该标签可用于在文件列表中显示相对路径。如果留空，则使用\n"
              "Doxygen 运行的目录作为要剥离的路径。\n"
              "\n"
              "请注意，您可以在此处指定绝对路径，也可以指定相对路径，这些路径将相对于 Doxygen 启动的目录。\n"
              "此标签要求标签 FULL_PATH_NAMES 设置为YES。"
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "STRIP_FROM_INC_PATH 标签可用于剥离类的文档中提到的路径的用户定义部分，该路径告诉读者应该包含哪个头文件才能使用类。如果留空，则只使用包\n"
              "含类定义的头文件的名称。否则，应该指定通常使用 -I 标志传递给编译器的包含路径列表。"
          );
  doc->add(
              "SHORT_NAMES",
              "如果 SHORT_NAMES 标签设置为 YES ，Doxygen 将生成更短（但可读性较差）的文件名。如果您的文件系统不支持长名称（如 DOS、Mac 或\n"
              "CD-ROM），这可能很有用。\n"
              "默认值为： NO。"
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "如果 JAVADOC_AUTOBRIEF 标签设置为 YES ，Doxygen 将把 Javadoc\n"
              "风格注释的第一行（直到第一个句点、问号或感叹号）解释为简要描述。如果设置为 NO ，Javadoc 风格将表现得像普通的 Qt 风格注释（因此需要显式的\n"
              "@brief 命令来获得简要描述。）\n"
              "默认值为： NO。"
          );
  doc->add(
              "JAVADOC_BANNER",
              "如果 JAVADOC_BANNER 标签设置为 YES ，Doxygen 将把像\n"
              "/***************\n"
              "这样的行解释为 Javadoc 风格注释\"横幅\"的开始。如果设置为 NO ，Javadoc 风格将表现得像普通注释，Doxygen 不会解释它。\n"
              "默认值为： NO。"
          );
  doc->add(
              "QT_AUTOBRIEF",
              "如果 QT_AUTOBRIEF 标签设置为 YES ，Doxygen 将把 Qt 风格注释的第一行（直到第一个句点、问号或感叹号）解释为简要描述。如果设置为\n"
              "NO ，Qt 风格将表现得像普通的 Qt 风格注释（因此需要显式的 \\brief 命令来获得简要描述。）\n"
              "默认值为： NO。"
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "MULTILINE_CPP_IS_BRIEF 标签可以设置为 YES ，使 Doxygen 将多行 C++ 特殊注释块（即 //! 或 ///\n"
              "注释块）视为简要描述。这曾经是默认行为。新的默认设置是将多行 C++ 注释块视为详细描述。如果您更喜欢旧的行为，请将此标签设置为 YES 。\n"
              "\n"
              "请注意，将此标签设置为 YES 也意味着不再识别 Rational Rose 注释。\n"
              "默认值为： NO。"
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "默认情况下，Python 文档字符串显示为预格式化文本，不能使用 Doxygen 的特殊命令。通过将 PYTHON_DOCSTRING 设置为 NO\n"
              "，可以使用 Doxygen 的特殊命令，并且文档字符串文档块的内容显示为 Doxygen 文档。\n"
              "默认值为： YES。"
          );
  doc->add(
              "INHERIT_DOCS",
              "如果 INHERIT_DOCS 标签设置为 YES ，则未记录的成员将继承其重新实现的任何已记录成员的文档。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "如果 SEPARATE_MEMBER_PAGES 标签设置为 YES ，Doxygen 将为每个成员生成一个新页面。如果设置为 NO\n"
              "，成员的文档将成为包含它的文件/类/命名空间的一部分。\n"
              "默认值为： NO。"
          );
  doc->add(
              "TAB_SIZE",
              "TAB_SIZE 标签可用于设置制表符中的空格数。Doxygen 使用此值在代码片段中用空格替换制表符。\n"
              "最小值：1，最大值：16，默认值：4。"
          );
  doc->add(
              "ALIASES",
              "此标签可用于指定多个在文档中充当命令的别名。别名的形式为：\n"
              "name=value\n"
              "例如添加\n"
              "\"sideeffect=@par Side Effects:^^\"\n"
              "将允许您在文档中放置命令 \\sideeffect （或 @sideeffect ），这将产生一个带有标题\"Side\n"
              "Effects:\"的用户定义段落。请注意，您不能在别名的值部分放置 \\n 来插入换行符（在结果输出中）。您可以在别名的值部分放置 ^^\n"
              "来插入换行符，就像原始文件中有物理换行符一样。当别名的值部分需要使用字面值 {、} 或 , 时，必须使用反斜杠 (\\) 进行转义。这可能会与命令 \\{ 和\n"
              "\\} 冲突。建议使用版本 @{ 和 @} ，或者使用双重转义 (\\\\{ 和 \\\\})"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "如果您的项目仅包含 C 源代码，请将 OPTIMIZE_OUTPUT_FOR_C 标签设置为 YES 。Doxygen 随后将生成更适合 C\n"
              "的输出。例如，将使用一些不同的名称。将省略所有成员的列表等。\n"
              "默认值为： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "如果您的项目仅包含 Java 或 Python 源代码，请将 OPTIMIZE_OUTPUT_JAVA 标签设置为 YES 。Doxygen\n"
              "随后将生成更适合该语言的输出。例如，命名空间将显示为包，限定作用域将看起来不同等。\n"
              "默认值为： NO。"
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "如果您的项目包含 Fortran 源代码，请将 OPTIMIZE_FOR_FORTRAN 标签设置为 YES 。Doxygen 随后将生成适合\n"
              "Fortran 的输出。\n"
              "默认值为： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "如果您的项目包含 VHDL 源代码，请将 OPTIMIZE_OUTPUT_VHDL 标签设置为 YES 。Doxygen 随后将生成适合 VHDL 的输出。\n"
              "默认值为： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "如果您的项目仅包含 Slice 源代码，请将 OPTIMIZE_OUTPUT_SLICE 标签设置为 YES 。Doxygen\n"
              "随后将生成更适合该语言的输出。例如，命名空间将显示为模块，类型将分成更多组等。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen 根据解析文件的扩展名选择要使用的解析器。使用此标签，您可以为给定扩展名分配要使用的解析器。Doxygen\n"
              "有内置映射，但您可以使用此标签覆盖或扩展它。格式为 ext=language，其中 ext 是文件扩展名，language 是 Doxygen\n"
              "支持的解析器之一：IDL、Java、JavaScript、Csharp (C#)、C、C++、Lex、D、PHP、md\n"
              "(Markdown)、Objective-C、Python、Slice、VHDL、Fortran（固定格式\n"
              "Fortran：FortranFixed，自由格式 Fortran：FortranFree，未知格式\n"
              "Fortran：Fortran。在后一种情况下，解析器尝试猜测代码是固定格式还是自由格式代码，这是 Fortran 类型文件的默认设置）。例如，要使\n"
              "Doxygen 将 .inc 文件视为 Fortran 文件（默认为 PHP），将 .f 文件视为 C 文件（默认为\n"
              "Fortran），请使用：inc=Fortran f=C。\n"
              "\n"
              "注意：对于没有扩展名的文件，您可以使用 no_extension 作为占位符。\n"
              "\n"
              "请注意，对于自定义扩展名，您还需要设置 FILE_PATTERNS，否则 Doxygen 不会读取这些文件。指定 no_extension 时，应将 *\n"
              "添加到 FILE_PATTERNS。\n"
              "\n"
              "注意，另请参阅 默认文件扩展名映射列表。"
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "如果启用了 MARKDOWN_SUPPORT 标签，Doxygen 将根据 Markdown 格式预处理所有注释，这允许更可读的文档。有关详细信息，请参阅\n"
              "https://daringfireball.net/projects/markdown/。Markdown 处理的输出进一步由 Doxygen\n"
              "处理，因此您可以将 Doxygen、HTML 和 XML 命令与 Markdown 格式混合使用。仅在向后兼容性问题时禁用。\n"
              "默认值为： YES。"
          );
  doc->add(
              "MARKDOWN_STRICT",
              "如果启用了 MARKDOWN_STRICT 标签，Doxygen 将在 Doxygen 的本机标记格式与 Markdown\n"
              "冲突的情况下，也将注释中的文本视为 Markdown 格式。这仅在使用反引号的情况下相关。Doxygen\n"
              "的本机标记样式允许单引号关闭以反引号开始的文本片段，然后将其视为引用文本片段，而在 Markdown\n"
              "中，此类文本片段被视为逐字文本，仅在找到第二个匹配的反引号时才关闭。此外，Doxygen 的本机标记格式要求在反引号部分中出现双引号时进行转义，而\n"
              "Markdown 不需要这样做。\n"
              "默认值为： YES。\n"
              "此标签要求标签 MARKDOWN_SUPPORT 设置为YES。"
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "当 TOC_INCLUDE_HEADINGS 标签设置为非零值时，直到该级别的所有标题都会自动包含在目录中，即使它们没有 id 属性。\n"
              "注意： 此功能目前仅适用于 Markdown 标题。\n"
              "最小值：0，最大值：99，默认值：6。\n"
              "此标签要求标签 MARKDOWN_SUPPORT 设置为YES。"
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "MARKDOWN_ID_STYLE 标签可用于指定用于为 Markdown 标题生成标识符的算法。注意：每个标识符都是唯一的。\n"
              "可能的值有：DOXYGEN 使用固定的'autotoc_md'字符串后跟从0开始的序列号和GITHUB\n"
              "使用标题的小写版本，将任何空格替换为'-'并删除标点符号.\n"
              "默认值为： DOXYGEN。\n"
              "此标签要求标签 MARKDOWN_SUPPORT 设置为YES。"
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "启用后，Doxygen 尝试将对应于已记录类或命名空间的单词链接到其相应的文档。可以通过在单词前放置 % 符号来防止个别情况下的此类链接，或者通过将\n"
              "AUTOLINK_SUPPORT 设置为 NO 来全局防止。 AUTOLINK_IGNORE_WORDS 标签中列出的单词被排除在自动链接之外。\n"
              "默认值为： YES。"
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "此标签指定一个单词列表，当与文档中单词的开头匹配时，如果通过 AUTOLINK_SUPPORT 启用了自动链接生成，将抑制自动链接生成。此列表不影响使用 #\n"
              "或 \\link 或 \\ref 命令显式创建的链接。\n"
              "此标签要求标签 AUTOLINK_SUPPORT 设置为YES。"
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "如果您使用 STL 类（即 std::string、std::vector 等），但不想将 STL 源代码的（标签文件）作为输入包含，则应将此标签设置为\n"
              "YES ，以便让 Doxygen 匹配参数包含 STL 类的函数声明和定义（例如 func(std::string); 与\n"
              "func(std::string) {}）。这也使涉及 STL 类的继承和协作图更加完整和准确。\n"
              "默认值为： NO。"
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "如果您使用 Microsoft 的 C++/CLI 语言，应将此选项设置为 YES 以启用解析支持。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SIP_SUPPORT",
              "如果您的项目仅包含 sip (see:\n"
              "https://www.riverbankcomputing.com/software) 源代码，请将 SIP_SUPPORT 标签设置为 YES\n"
              "。Doxygen 将像普通 C++ 一样解析它们，但会假设所有类在没有显式保护关键字时都使用公共继承而不是私有继承。\n"
              "默认值为： NO。"
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "对于 Microsoft 的 IDL，有 propget 和 propput 属性来指示属性的 getter 和 setter 方法。将此选项设置为 YES\n"
              "将使 Doxygen 在文档中用属性替换 get 和 set\n"
              "方法。这仅在方法确实是获取或设置简单类型时才有效。如果不是这种情况，或者您想无论如何显示方法，应将此选项设置为 NO 。\n"
              "默认值为： YES。"
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "如果在文档中使用了成员分组，并且 DISTRIBUTE_GROUP_DOC 标签设置为 YES ，那么 Doxygen\n"
              "将为组中的其他成员重用组中第一个成员的文档（如果有）。默认情况下，组的所有成员必须显式记录。\n"
              "默认值为： NO。"
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "如果将结构体或类添加到组中并启用了此选项，则任何嵌套的类或结构体也会添加到同一组中。默认情况下，此选项被禁用，必须通过 \\ingroup\n"
              "显式添加嵌套复合类型。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SUBGROUPING",
              "将 SUBGROUPING 标签设置为 YES 以允许相同类型的类成员组（例如一组公共函数）作为该类型的子组放置（例如在公共函数部分下）。将其设置为 NO\n"
              "以防止子组化。或者，可以使用 \\nosubgrouping 命令按类执行此操作。\n"
              "默认值为： YES。"
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "当 INLINE_GROUPED_CLASSES 标签设置为 YES 时，类、结构体和联合体显示在包含它们的组中（例如使用\n"
              "\\ingroup），而不是在单独的页面上（对于 HTML 和 Man 页面）或部分中（对于 LaTeX 和 RTF）。\n"
              "\n"
              "请注意，此功能不能与 SEPARATE_MEMBER_PAGES 结合使用。\n"
              "默认值为： NO。"
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "当 INLINE_SIMPLE_STRUCTS 标签设置为 YES 时，仅具有公共数据字段或简单 typedef\n"
              "字段的结构体、类和联合体将显示在定义它们的作用域的文档中（即文件、命名空间或组文档），前提是此作用域已记录。如果设置为 NO\n"
              "，结构体、类和联合体将显示在单独的页面上（对于 HTML 和 Man 页面）或部分中（对于 LaTeX 和 RTF）。\n"
              "默认值为： NO。"
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "启用 TYPEDEF_HIDES_STRUCT 标签后，结构体、联合体或枚举的 typedef 将记录为具有 typedef\n"
              "名称的结构体、联合体或枚举。因此 typedef struct TypeS {} TypeT 将在文档中显示为名为 TypeT\n"
              "的结构体。禁用时，typedef 将显示为文件、命名空间或类的成员。结构体将命名为 TypeS 。这通常对于 C\n"
              "代码很有用，如果编码约定要求所有复合类型都是 typedef 的，并且只引用 typedef，从不引用标签名称。\n"
              "默认值为： NO。"
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "可以使用 LOOKUP_CACHE_SIZE\n"
              "设置符号查找缓存的大小。此缓存用于根据符号的名称和作用域解析符号。由于这可能是一个昂贵的过程，并且通常相同的符号在代码中出现多次，Doxygen\n"
              "会保留一个预解析符号的缓存。如果缓存太小，Doxygen\n"
              "会变慢。如果缓存太大，会浪费内存。缓存大小由以下公式给出：2^(16+LOOKUP_CACHE_SIZE)。有效范围为 0..9，默认值为\n"
              "0，对应于缓存大小 2^16=65536 个符号。在运行结束时，Doxygen 将报告缓存使用情况并从速度角度建议最佳缓存大小。\n"
              "最小值：0，最大值：9，默认值：0。"
          );
  doc->add(
              "NUM_PROC_THREADS",
              "NUM_PROC_THREADS 指定 Doxygen 在处理期间允许使用的线程数。设置为 0 时，Doxygen\n"
              "将根据系统中可用的核心数进行设置。您可以将其显式设置为大于 0 的值，以更好地控制 CPU\n"
              "负载和处理速度之间的平衡。目前只有输入处理可以使用多线程完成。由于这仍然是一个实验性功能，默认值设置为\n"
              "1，这实际上禁用了并行处理。请报告您遇到的任何问题。并行生成 dot 图由 DOT_NUM_THREADS 设置控制。\n"
              "最小值：0，最大值：512，默认值：1。"
          );
  doc->add(
              "TIMESTAMP",
              "如果 TIMESTAMP 标签设置为不同于 NO 的值，则每个生成的页面将包含页面生成时的日期或日期和时间。将此设置为 NO 有助于比较多次运行的输出。\n"
              "可能的值有：YES, NO, DATETIME和DATE.\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_ALL",
              "如果 EXTRACT_ALL 标签设置为 YES ，Doxygen\n"
              "将假设文档中的所有实体都已记录，即使没有可用的文档。私有类成员和静态文件成员将被隐藏，除非分别设置了 EXTRACT_PRIVATE 或\n"
              "EXTRACT_STATIC 标签为 YES 。\n"
              "注意： 这也将禁用通常在 WARNINGS 设置为 YES 时产生的有关未记录成员的警告。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "如果 EXTRACT_PRIVATE 标签设置为 YES ，类的所有私有成员将包含在文档中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "如果 EXTRACT_PRIV_VIRTUAL 标签设置为 YES ，类的已记录私有虚拟方法将包含在文档中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "如果 EXTRACT_PACKAGE 标签设置为 YES ，所有具有包或内部作用域的成员将包含在文档中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_STATIC",
              "如果 EXTRACT_STATIC 标签设置为 YES ，文件的所有静态成员将包含在文档中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "如果 EXTRACT_LOCAL_CLASSES 标签设置为 YES ，在源文件中本地定义的类（和结构体）将包含在文档中。如果设置为 NO\n"
              "，则只包含在头文件中定义的类。对 Java 源代码没有任何影响。\n"
              "默认值为： YES。"
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "此标志仅对 Objective-C 代码有用。如果设置为 YES ，在实现部分定义但不在接口中的本地方法将包含在文档中。如果设置为 NO\n"
              "，则只包含接口中的方法。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "如果此标志设置为 YES ，匿名命名空间的成员将被提取并在文档中显示为名为 'anonymous_namespace{file}' 的命名空间，其中\n"
              "file 将替换为包含匿名命名空间的文件的基本名称。默认情况下，匿名命名空间是隐藏的。\n"
              "默认值为： NO。"
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "如果此标志设置为 YES ，声明中未命名参数的名称将由相应的定义确定。默认情况下，未命名参数在输出中保持未命名。\n"
              "默认值为： YES。"
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "如果 HIDE_UNDOC_MEMBERS 标签设置为 YES ，Doxygen 将隐藏已记录类或文件中的所有未记录成员。如果设置为 NO\n"
              "，这些成员将包含在各种概述中，但不生成文档部分。如果启用了 EXTRACT_ALL，此选项无效。\n"
              "默认值为： NO。"
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "如果 HIDE_UNDOC_CLASSES 标签设置为 YES ，Doxygen 将隐藏类层次结构中通常可见的所有未记录类。如果设置为 NO\n"
              "，这些类将包含在各种概述中。如果启用，此选项还将隐藏未记录的 C++ 概念。如果启用了 EXTRACT_ALL，此选项无效。\n"
              "默认值为： NO。"
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "如果 HIDE_UNDOC_NAMESPACES 标签设置为 YES ，Doxygen 将隐藏命名空间层次结构中通常可见的所有未记录命名空间。如果设置为\n"
              "NO ，这些命名空间将包含在各种概述中。如果启用了 EXTRACT_ALL，此选项无效。\n"
              "默认值为： YES。"
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "如果 HIDE_FRIEND_COMPOUNDS 标签设置为 YES ，Doxygen 将隐藏所有友元声明。如果设置为 NO ，这些声明将包含在文档中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "如果 HIDE_IN_BODY_DOCS 标签设置为 YES ，Doxygen 将隐藏在函数体内找到的任何文档块。如果设置为 NO\n"
              "，这些块将附加到函数的详细文档块。\n"
              "默认值为： NO。"
          );
  doc->add(
              "INTERNAL_DOCS",
              "INTERNAL_DOCS 标签确定是否包含在 \\internal 命令后键入的文档。如果标签设置为 NO ，则文档将被排除。将其设置为 YES\n"
              "以包含内部文档。\n"
              "默认值为： NO。"
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "通过正确设置选项 CASE_SENSE_NAMES ，Doxygen\n"
              "将能够更好地匹配底层文件系统的功能。如果文件系统区分大小写（即它支持同一目录中名称仅大小写不同的文件），则必须将选项设置为 YES\n"
              "以正确处理输入中出现的此类文件。对于不区分大小写的文件系统，应将选项设置为 NO 以正确处理为仅大小写不同的符号编写的输出文件，例如对于两个类，一个名为\n"
              "CLASS ，另一个名为 Class ，并且还支持引用文件而无需指定完全匹配的大小写。在 Windows（包括 Cygwin）和 macOS\n"
              "上，用户通常应将此选项设置为 NO ，而在 Linux 或其他 Unix 系统上，通常应将其设置为 YES 。\n"
              "可能的值有：SYSTEM, NO和YES.\n"
              "默认值为： SYSTEM。"
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "如果 HIDE_SCOPE_NAMES 标签设置为 NO ，Doxygen 将在文档中显示具有完整类和命名空间作用域的成员。如果设置为 YES\n"
              "，作用域将被隐藏。\n"
              "默认值为： NO。"
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "如果 HIDE_COMPOUND_REFERENCE 标签设置为 NO （默认），Doxygen 将在页面标题后附加额外的文本，例如类参考。如果设置为\n"
              "YES ，复合引用将被隐藏。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SHOW_HEADERFILE",
              "如果 SHOW_HEADERFILE 标签设置为 YES ，则类的文档将显示需要包含哪个文件才能使用该类。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "如果 SHOW_INCLUDE_FILES 标签设置为 YES ，Doxygen 将在文件的文档中放置该文件包含的文件列表。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "如果 SHOW_GROUPED_MEMB_INC 标签设置为 YES ，Doxygen\n"
              "将为每个分组成员添加一个包含语句到文档中，告诉读者需要包含哪个文件才能使用该成员。\n"
              "默认值为： NO。"
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "如果 FORCE_LOCAL_INCLUDES 标签设置为 YES ，Doxygen 将在文档中列出使用双引号而不是尖括号的包含文件。\n"
              "默认值为： NO。"
          );
  doc->add(
              "INLINE_INFO",
              "如果 INLINE_INFO 标签设置为 YES ，则会在内联成员的文档中插入 [inline] 标记。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "如果 SORT_MEMBER_DOCS 标签设置为 YES ，Doxygen 将按成员名称字母顺序对文件和类成员的（详细）文档进行排序。如果设置为 NO\n"
              "，成员将按声明顺序出现。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "如果 SORT_BRIEF_DOCS 标签设置为 YES ，Doxygen 将按成员名称字母顺序对文件、命名空间和类成员的简要描述进行排序。如果设置为 NO\n"
              "，成员将按声明顺序出现。请注意，这也会影响类列表中类的顺序。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "如果 SORT_MEMBERS_CTORS_1ST 标签设置为 YES ，Doxygen\n"
              "将对类成员的（简要和详细）文档进行排序，使构造函数和析构函数首先列出。如果设置为 NO ，构造函数将按 SORT_BRIEF_DOCS 和\n"
              "SORT_MEMBER_DOCS 定义的各自顺序出现。\n"
              "注意： 如果 SORT_BRIEF_DOCS 设置为 NO ，则在排序简要成员文档时忽略此选项。\n"
              "注意： 如果 SORT_MEMBER_DOCS 设置为 NO ，则在排序详细成员文档时忽略此选项。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "如果 SORT_GROUP_NAMES 标签设置为 YES ，Doxygen 将按字母顺序对组名称的层次结构进行排序。如果设置为 NO\n"
              "，组名称将按其定义顺序出现。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "如果 SORT_BY_SCOPE_NAME 标签设置为 YES ，类列表将按完全限定名称（包括命名空间）排序。如果设置为 NO\n"
              "，类列表将仅按类名排序，不包括命名空间部分。\n"
              "注意： 如果 HIDE_SCOPE_NAMES 设置为 YES ，此选项不太有用。\n"
              "注意： 此选项仅适用于类列表，不适用于字母列表。\n"
              "默认值为： NO。"
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "如果启用了 STRICT_PROTO_MATCHING 选项，并且 Doxygen\n"
              "无法正确解析函数的所有参数类型，它将拒绝成员函数的原型和实现之间的匹配，即使只有一个候选者或者通过简单的字符串匹配很明显应该选择哪个候选者。通过禁用\n"
              "STRICT_PROTO_MATCHING ，Doxygen 仍将在这种情况下接受原型和实现之间的匹配。\n"
              "默认值为： NO。"
          );
  doc->add(
              "GENERATE_TODOLIST",
              "GENERATE_TODOLIST 标签可用于启用（ YES ）或禁用（ NO ）待办事项列表。此列表是通过在文档中放置 \\todo 命令创建的。\n"
              "默认值为： YES。"
          );
  doc->add(
              "GENERATE_TESTLIST",
              "GENERATE_TESTLIST 标签可用于启用（ YES ）或禁用（ NO ）测试列表。此列表是通过在文档中放置 \\test 命令创建的。\n"
              "默认值为： YES。"
          );
  doc->add(
              "GENERATE_BUGLIST",
              "GENERATE_BUGLIST 标签可用于启用（ YES ）或禁用（ NO ）错误列表。此列表是通过在文档中放置 \\bug 命令创建的。\n"
              "默认值为： YES。"
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "GENERATE_DEPRECATEDLIST 标签可用于启用（ YES ）或禁用（ NO ）弃用列表。此列表是通过在文档中放置 \\deprecated\n"
              "命令创建的。\n"
              "默认值为： YES。"
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "GENERATE_REQUIREMENTS 标签可用于启用（ YES ）或禁用（ NO ）需求页面。启用后，当输入中至少出现一个带有\n"
              "\\requirement 命令的注释块时，此页面会自动创建。\n"
              "默认值为： YES。"
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "REQ_TRACEABILITY_INFO 标签控制是否在需求页面上显示可追溯性信息（仅在使用 \\requirement 注释块时相关）。设置 NO\n"
              "将完全禁用可追溯性信息。设置 UNSATISFIED_ONLY 将显示缺少满足关系（通过命令：\\satisfies）的需求列表。类似地，设置\n"
              "UNVERIFIED_ONLY 将显示缺少验证关系（通过命令：\\verifies）的需求列表。将标签设置为 YES（默认）将在适用时显示两个列表。\n"
              "可能的值有：YES, NO, UNSATISFIED_ONLY和UNVERIFIED_ONLY.\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_REQUIREMENTS 设置为YES。"
          );
  doc->add(
              "ENABLED_SECTIONS",
              "ENABLED_SECTIONS 标签可用于启用条件文档部分，由 \\if <section_label> ... \\endif 和 \\cond\n"
              "<section_label> ... \\endcond 块标记。"
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "MAX_INITIALIZER_LINES\n"
              "标签确定变量或宏/定义的初始值可以显示的最大行数，以便它出现在文档中。如果初始化器包含的行数超过此处指定的数量，它将被隐藏。使用值 0\n"
              "可完全隐藏初始化器。无论此设置如何，都可以在文档中使用 \\showinitializer 或 \\hideinitializer\n"
              "命令控制单个变量和宏/定义的值的外观。\n"
              "最小值：0，最大值：10000，默认值：30。"
          );
  doc->add(
              "SHOW_USED_FILES",
              "将 SHOW_USED_FILES 标签设置为 NO 以禁用类和结构体文档底部生成的文件列表。如果设置为 YES ，列表将提及用于生成文档的文件。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SHOW_FILES",
              "将 SHOW_FILES 标签设置为 NO 以禁用文件页面的生成。这将从快速索引和文件夹树视图（如果指定）中删除文件条目。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SHOW_NAMESPACES",
              "将 SHOW_NAMESPACES 标签设置为 NO 以禁用命名空间页面的生成。这将从快速索引和文件夹树视图（如果指定）中删除命名空间条目。\n"
              "默认值为： YES。"
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "FILE_VERSION_FILTER 标签可用于指定 Doxygen\n"
              "应调用的程序或脚本，以获取每个文件的当前版本（通常来自版本控制系统）。Doxygen 将通过执行（通过 popen()）命令 command\n"
              "input_file 来调用程序，其中 command 是 FILE_VERSION_FILTER 标签的值， input_file 是 Doxygen\n"
              "提供的输入文件的名称。程序写入标准输出的任何内容都用作文件版本。例如，请参阅文档。"
          );
  doc->add(
              "LAYOUT_FILE",
              "LAYOUT_FILE 标签可用于指定 Doxygen 将解析的布局文件。布局文件以独立于输出格式的方式控制生成输出文件的全局结构。要创建表示\n"
              "Doxygen 默认值的布局文件，请使用 -l 选项运行 Doxygen。您可以选择在选项后指定文件名，如果省略，则使用 DoxygenLayout.xml\n"
              "作为布局文件的名称。另请参阅第 \"Changing the layout of pages\" 节以获取信息。\n"
              "\n"
              "请注意，如果您从包含名为 DoxygenLayout.xml 的文件的目录运行 Doxygen，即使 LAYOUT_FILE 标签为空，Doxygen\n"
              "也会自动解析它。"
          );
  doc->add(
              "CITE_BIB_FILES",
              "CITE_BIB_FILES 标签可用于指定一个或多个包含参考定义的 bib 文件。这必须是 .bib 文件列表。如果省略，会自动附加 .bib\n"
              "扩展名。这需要安装 bibtex 工具。另请参阅 https://en.wikipedia.org/wiki/BibTeX 以获取更多信息。对于\n"
              "LaTeX，可以使用 LATEX_BIB_STYLE 控制参考文献的样式。要使用此功能，您需要在搜索路径中有 bibtex 和 perl 可用。另请参阅\n"
              "\\cite 以获取有关如何创建引用的信息。"
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "EXTERNAL_TOOL_PATH 标签可用于扩展搜索路径（PATH 环境变量），以便可以找到 latex 和 gs 等外部工具。\n"
              "注意： 使用 EXTERNAL_TOOL_PATH 指定的目录添加到 PATH 变量已指定的路径前面，并按指定的顺序添加。\n"
              "注意： 此选项对于 macOS 版本 14 (Sonoma) 及更高版本特别有用，当从 Doxywizard 运行 Doxygen\n"
              "时，因为在这种情况下，PATH 的任何用户定义更改都会被忽略。macOS 上的一个典型示例是设置\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "与标准路径一起，Doxygen 在启动外部工具时使用的完整搜索路径将变为\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "QUIET 标签可用于打开/关闭 Doxygen 生成到标准输出的消息。如果 QUIET 设置为 YES ，这意味着消息已关闭。\n"
              "默认值为： NO。"
          );
  doc->add(
              "WARNINGS",
              "WARNINGS 标签可用于打开/关闭 Doxygen 生成到标准错误（ stderr ）的警告消息。如果 WARNINGS 设置为 YES\n"
              "，这意味着警告已打开。\n"
              "\n"
              "提示：在编写文档时打开警告。\n"
              "默认值为： YES。"
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "如果 WARN_IF_UNDOCUMENTED 标签设置为 YES ，Doxygen 将为未记录的成员生成警告。如果 EXTRACT_ALL 设置为 YES\n"
              "，则此标志将自动禁用。\n"
              "默认值为： YES。"
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "如果 WARN_IF_DOC_ERROR 标签设置为 YES ，Doxygen\n"
              "将为文档中的潜在错误生成警告，例如在已记录的函数中两次记录某些参数，或记录不存在的参数或错误使用标记命令。\n"
              "默认值为： YES。"
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "如果 WARN_IF_INCOMPLETE_DOC 设置为 YES ，Doxygen 将警告不完整的函数参数文档。如果设置为 NO ，Doxygen\n"
              "将接受某些参数没有文档而不发出警告。\n"
              "默认值为： YES。"
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "可以启用此 WARN_NO_PARAMDOC 选项以获取已记录但没有参数或返回值文档的函数的警告。如果设置为 NO ，Doxygen\n"
              "只会警告错误的参数文档，而不会警告缺少文档。如果 EXTRACT_ALL 设置为 YES ，则此标志将自动禁用。另请参阅\n"
              "WARN_IF_INCOMPLETE_DOC\n"
              "默认值为： NO。"
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "如果 WARN_IF_UNDOC_ENUM_VAL 选项设置为 YES ，Doxygen 将警告未记录的枚举值。如果设置为 NO ，Doxygen\n"
              "将接受未记录的枚举值。如果 EXTRACT_ALL 设置为 YES ，则此标志将自动禁用。\n"
              "默认值为： NO。"
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "如果 WARN_LAYOUT_FILE 选项设置为 YES ，Doxygen 将警告在解析用户定义的布局文件时发现的问题，例如缺少或错误的元素。另请参阅\n"
              "LAYOUT_FILE 以获取详细信息。如果设置为 NO ，布局文件的问题将被抑制。\n"
              "默认值为： YES。"
          );
  doc->add(
              "WARN_AS_ERROR",
              "如果 WARN_AS_ERROR 标签设置为 YES ，则 Doxygen 将在遇到警告时立即停止。如果 WARN_AS_ERROR 标签设置为\n"
              "FAIL_ON_WARNINGS ，则 Doxygen 将继续运行，就像 WARN_AS_ERROR 标签设置为 NO 一样，但在 Doxygen\n"
              "过程结束时，Doxygen 将返回非零状态。如果 WARN_AS_ERROR 标签设置为 FAIL_ON_WARNINGS_PRINT ，则 Doxygen\n"
              "的行为类似于 FAIL_ON_WARNINGS ，但在未定义 WARN_LOGFILE 的情况下，Doxygen\n"
              "不会在其他消息之间写入警告消息，而是在运行结束时写入它们，如果定义了 WARN_LOGFILE，警告消息除了在定义的文件中外，还会在运行结束时显示，除非\n"
              "WARN_LOGFILE 定义为 - 即标准输出（stdout），在这种情况下，行为将保持为设置 FAIL_ON_WARNINGS。\n"
              "可能的值有：NO, YES, FAIL_ON_WARNINGS和FAIL_ON_WARNINGS_PRINT.\n"
              "默认值为： NO。"
          );
  doc->add(
              "WARN_FORMAT",
              "WARN_FORMAT 标签确定 Doxygen 可以生成的警告消息的格式。字符串应包含 $file、$line 和 $text\n"
              "标签，它们将被警告起源的文件和行号以及警告文本替换。可选地，格式可以包含 $version，它将被文件的版本替换（如果可以通过\n"
              "FILE_VERSION_FILTER 获取）\n"
              "另请参阅： WARN_LINE_FORMAT\n"
              "默认值为： $file:$line: $text。"
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "在 WARN_FORMAT 命令的 $text 部分中，可能会给出对更具体位置的引用。为了更容易跳转到此位置（在 Doxygen\n"
              "之外），用户可以定义自定义的\"剪切\"/\"粘贴\"字符串。示例：\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "另请参阅： WARN_FORMAT\n"
              "默认值为： at line $line of file $file。"
          );
  doc->add(
              "WARN_LOGFILE",
              "WARN_LOGFILE 标签可用于指定应将警告和错误消息写入的文件。如果留空，输出将写入标准错误（stderr）。如果无法打开指定的文件进行写入，警告和\n"
              "错误消息将写入标准错误。当指定文件 - 时，警告和错误消息将写入标准输出（stdout）。"
          );
  doc->add(
              "INPUT",
              "INPUT 标签用于指定包含已记录源文件的文件和/或目录。您可以输入文件名如 myfile.cpp 或目录如 /usr/src/myproject\n"
              "。用空格分隔文件或目录。另请参阅 FILE_PATTERNS 和 EXTENSION_MAPPING\n"
              "注意： 如果此标签为空，则搜索当前目录。"
          );
  doc->add(
              "INPUT_ENCODING",
              "此标签可用于指定 Doxygen 解析的源文件的字符编码。Doxygen 内部使用 UTF-8 编码。Doxygen 使用 libiconv（或 libc\n"
              "内置的 iconv）进行转码。请参阅 libiconv 文档 (see:\n"
              "https://www.gnu.org/software/libiconv/)以获取可能的编码列表。\n"
              "另请参阅： INPUT_FILE_ENCODING\n"
              "默认值为： UTF-8。"
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "此标签可用于指定 Doxygen 解析的源文件的字符编码。 INPUT_FILE_ENCODING 标签可用于基于每个文件模式指定字符编码。Doxygen\n"
              "将文件名与每个模式进行比较，如果有匹配，则应用编码而不是默认的 INPUT_ENCODING。字符编码是以下形式的列表：pattern=encoding（如\n"
              "*.php=ISO-8859-1）。\n"
              "另请参阅： INPUT_ENCODING 以获取有关支持编码的更多信息。"
          );
  doc->add(
              "FILE_PATTERNS",
              "如果 INPUT 标签的值包含目录，则可以使用 FILE_PATTERNS 标签指定一个或多个通配符模式（如 *.cpp 和 *.h）来过滤目录中的源文件。\n"
              "\n"
              "请注意，对于自定义扩展名或未直接支持的扩展名，您还需要为扩展名设置 EXTENSION_MAPPING，否则 Doxygen 不会读取这些文件。\n"
              "\n"
              "请注意，默认选中的文件模式列表可能与 默认文件扩展名映射列表不同。\n"
              "\n"
              "如果留空，则测试以下模式：*.c, *.cc, *.cxx, *.cxxm, *.cpp, *.cppm, *.ccm, *.c++, *.c++m,\n"
              "*.java, *.ii, *.ixx, *.ipp, *.i++, *.inl, *.idl, *.ddl, *.odl, *.h, *.hh,\n"
              "*.hxx, *.hpp, *.h++, *.l, *.cs, *.d, *.php, *.php4, *.php5, *.phtml, *.inc,\n"
              "*.m, *.markdown, *.md, *.mm, *.dox (to be provided as Doxygen C comment),\n"
              "*.py, *.pyw, *.f90, *.f95, *.f03, *.f08, *.f18, *.f, *.for, *.vhd, *.vhdl,\n"
              "*.ucf, *.qsf和*.ice."
          );
  doc->add(
              "RECURSIVE",
              "RECURSIVE 标签可用于指定是否也应搜索输入文件的子目录。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXCLUDE",
              "EXCLUDE 标签可用于指定应从 INPUT 源文件中排除的文件和/或目录。这样，您可以轻松地从根目录使用 INPUT 标签指定的目录树中排除子目录。\n"
              "\n"
              "请注意，相对路径相对于运行 Doxygen 的目录。"
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "EXCLUDE_SYMLINKS 标签可用于选择是否从输入中排除作为符号链接（Unix 文件系统功能）的文件或目录。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "如果 INPUT 标签的值包含目录，则可以使用 EXCLUDE_PATTERNS 标签指定一个或多个通配符模式，以从这些目录中排除某些文件。\n"
              "\n"
              "请注意，通配符与具有绝对路径的文件匹配，因此要排除所有测试目录，例如使用模式 */test/*"
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "EXCLUDE_SYMBOLS\n"
              "标签可用于指定一个或多个应从输出中排除的符号名称（命名空间、类、函数等）。符号名称可以是完全限定名称、单词，或者如果使用通配符\n"
              "*，则可以是子字符串。示例：ANamespace、AClass、ANamespace::AClass、ANamespace::*Test"
          );
  doc->add(
              "EXAMPLE_PATH",
              "EXAMPLE_PATH 标签可用于指定一个或多个包含示例代码片段的文件或目录，这些代码片段被包含（请参阅 \\include 命令）。"
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "如果 EXAMPLE_PATH 标签的值包含目录，则可以使用 EXAMPLE_PATTERNS 标签指定一个或多个通配符模式（如 *.cpp 和\n"
              "*.h）来过滤目录中的源文件。如果留空，则包含所有文件。"
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "如果 EXAMPLE_RECURSIVE 标签设置为 YES ，则无论 RECURSIVE 标签的值如何，都将搜索子目录以查找与 \\include 或\n"
              "\\dontinclude 命令一起使用的输入文件。\n"
              "默认值为： NO。"
          );
  doc->add(
              "IMAGE_PATH",
              "IMAGE_PATH 标签可用于指定一个或多个包含要包含在文档中的图像的文件或目录（请参阅 \\image 命令）。"
          );
  doc->add(
              "INPUT_FILTER",
              "INPUT_FILTER 标签可用于指定 Doxygen 应为每个输入文件调用的过滤器。Doxygen 将通过执行（通过\n"
              "popen()）命令来调用过滤器程序：\n"
              "\n"
              "<filter> <input-file>\n"
              "\n"
              "其中 <filter> 是 INPUT_FILTER 标签的值，<input-file> 是输入文件的名称。Doxygen\n"
              "随后将使用过滤器程序写入标准输出的输出进行进一步处理。如果指定了 FILTER_PATTERNS，则忽略此标签。\n"
              "\n"
              "请注意，过滤器不得添加或删除行；它在扫描代码之前应用，但在生成输出代码时不应用。如果添加或删除行，锚点将无法正确放置。\n"
              "\n"
              "请注意，Doxygen 将使用处理并写入标准输出的数据进行进一步处理，因此不应将其他任何内容（如调试语句或使用的命令（因此在 Windows\n"
              "批处理文件中始终使用 @echo OFF））写入标准输出。\n"
              "\n"
              "请注意，对于自定义扩展名或未直接支持的扩展名，您还需要为扩展名设置 EXTENSION_MAPPING，否则 Doxygen 不会正确处理这些文件。\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "FILTER_PATTERNS 标签可用于基于每个文件模式指定过滤器。Doxygen\n"
              "将文件名与每个模式进行比较，如果有匹配，则应用过滤器。过滤器是以下形式的列表：pattern=filter（如\n"
              "*.cpp=my_cpp_filter）。请参阅 INPUT_FILTER 以获取有关如何使用过滤器的更多信息。如果 FILTER_PATTERNS\n"
              "标签为空或没有模式匹配文件名，则应用 INPUT_FILTER。\n"
              "\n"
              "请注意，对于自定义扩展名或未直接支持的扩展名，您还需要为扩展名设置 EXTENSION_MAPPING，否则 Doxygen 不会正确处理这些文件。\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "如果 FILTER_SOURCE_FILES 标签设置为 YES ，则输入过滤器（如果使用 INPUT_FILTER\n"
              "设置）也将用于过滤用于生成要浏览的源文件的输入文件（即当 SOURCE_BROWSER 设置为 YES 时）。\n"
              "默认值为： NO。"
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "FILTER_SOURCE_PATTERNS 标签可用于基于每个文件模式指定源过滤器。模式将覆盖 FILTER_PATTERN\n"
              "的设置（如果有），也可以使用 *.ext= 禁用特定模式的源过滤器（因此不命名过滤器）。\n"
              "此标签要求标签 FILTER_SOURCE_FILES 设置为YES。"
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "如果 USE_MDFILE_AS_MAINPAGE 标签引用作为输入一部分的 markdown\n"
              "文件的名称，则其内容将放置在主页面上（index.html）。如果您的项目在例如 GitHub 上，并且想要将介绍页面也重用于 Doxygen\n"
              "输出，这可能很有用。"
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "如果 IMPLICIT_DIR_DOCS 标签设置为 YES ，则在项目根目录的子目录中找到的任何 README.md 文件都将用作该子目录的文档，除非\n"
              "README.md 以 \\dir、\\page 或 \\mainpage 命令开头。如果设置为 NO ，则需要 README.md 文件以显式的 \\dir\n"
              "命令开头才能用作目录文档。\n"
              "默认值为： YES。"
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "Fortran 标准规定，对于固定格式的 Fortran 代码，从位置 72\n"
              "开始的所有字符都被视为注释。一个常见的扩展是允许在自动注释开始之前有更长的行。设置 FORTRAN_COMMENT_AFTER\n"
              "也将使在自动注释开始之前可以处理更长的行。\n"
              "最小值：7，最大值：10000，默认值：72。"
          );
  doc->add(
              "SOURCE_BROWSER",
              "如果 SOURCE_BROWSER 标签设置为 YES ，则将生成源文件列表。已记录的实体将与这些源交叉引用。\n"
              "\n"
              "注意：要摆脱生成输出中的所有源代码，请确保也将 VERBATIM_HEADERS 设置为 NO 。\n"
              "默认值为： NO。"
          );
  doc->add(
              "INLINE_SOURCES",
              "将 INLINE_SOURCES 标签设置为 YES 将直接在文档中包含函数体、多行宏、枚举或列表初始化变量。\n"
              "默认值为： NO。"
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "将 STRIP_CODE_COMMENTS 标签设置为 YES 将指示 Doxygen 从生成的源代码片段中隐藏任何特殊注释块。普通的 C、C++ 和\n"
              "Fortran 注释将始终可见。\n"
              "默认值为： YES。"
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "如果 REFERENCED_BY_RELATION 标签设置为 YES ，则对于每个已记录的实体，将列出引用它的所有已记录函数。\n"
              "默认值为： NO。"
          );
  doc->add(
              "REFERENCES_RELATION",
              "如果 REFERENCES_RELATION 标签设置为 YES ，则对于每个已记录的函数，将列出该函数调用/使用的所有已记录实体。\n"
              "默认值为： NO。"
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "如果 REFERENCES_LINK_SOURCE 标签设置为 YES 且 SOURCE_BROWSER 标签设置为 YES ，则\n"
              "REFERENCES_RELATION 和 REFERENCED_BY_RELATION 列表中函数的超链接将链接到源代码。否则，它们将链接到文档。\n"
              "默认值为： YES。"
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "如果启用了 SOURCE_TOOLTIPS\n"
              "（默认），则在源代码中悬停超链接将显示一个工具提示，其中包含其他信息，如原型、简要描述以及指向定义和文档的链接。由于这会使 HTML\n"
              "文件更大并使大文件的加载速度稍慢，您可以选择禁用此功能。\n"
              "默认值为： YES。\n"
              "此标签要求标签 SOURCE_BROWSER 设置为YES。"
          );
  doc->add(
              "USE_HTAGS",
              "如果 USE_HTAGS 标签设置为 YES ，则对源代码的引用将指向由 htags(1) 工具生成的 HTML，而不是 Doxygen 内置的源浏览器。\n"
              "htags 工具是 GNU 全局源标记系统的一部分（请参阅\n"
              "https://www.gnu.org/software/global/global.html）。您需要 4.8.6 或更高版本。\n"
              "\n"
              "要使用它，请执行以下操作：\n"
              "- 安装最新版本的 global\n"
              "- 在配置文件中启用 SOURCE_BROWSER 和 USE_HTAGS\n"
              "- 确保 INPUT 指向源代码树的根目录\n"
              "- 正常运行 doxygen\n"
              "\n"
              "Doxygen 将调用 htags （它将依次调用 gtags ），因此这些工具必须可从命令行获得（即在搜索路径中）。\n"
              "\n"
              "结果：链接到源代码的链接现在将指向 htags 的输出，而不是 Doxygen 生成的源浏览器。\n"
              "默认值为： NO。\n"
              "此标签要求标签 SOURCE_BROWSER 设置为YES。"
          );
  doc->add(
              "VERBATIM_HEADERS",
              "如果 VERBATIM_HEADERS 标签设置为 YES ，Doxygen 将为每个指定包含的类生成头文件的逐字副本。设置为 NO 以禁用此功能。\n"
              "另请参阅： 第 \\class 节。\n"
              "默认值为： YES。"
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "如果 CLANG_ASSISTED_PARSING 标签设置为 YES ，Doxygen 将使用 clang 解析器 (see:\n"
              "http://clang.llvm.org/)进行更准确的解析，但会降低性能。这对于模板丰富的 C++ 代码特别有用，因为 Doxygen\n"
              "的内置解析器缺少必要的类型信息。\n"
              "注意： 此选项的可用性取决于 Doxygen 是否使用 CMake 的 -Duse_libclang=ON 选项生成。\n"
              "默认值为： NO。"
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "如果 CLANG_ASSISTED_PARSING 标签设置为 YES 且 CLANG_ADD_INC_PATHS 标签设置为 YES ，Doxygen\n"
              "将把每个输入的目录添加到包含路径。\n"
              "默认值为： YES。\n"
              "此标签要求标签 CLANG_ASSISTED_PARSING 设置为YES。"
          );
  doc->add(
              "CLANG_OPTIONS",
              "如果启用了 clang 辅助解析，您可以向编译器提供在调用编译器时通常使用的命令行选项。请注意，Doxygen 已经为使用 INPUT 和\n"
              "INCLUDE_PATH 指定的文件和目录设置了包含路径。\n"
              "此标签要求标签 CLANG_ASSISTED_PARSING 设置为YES。"
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "如果启用了 clang 辅助解析，您可以为 clang 解析器提供包含名为 compile_commands.json 的文件的目录的路径。此文件是\n"
              "编译数据库 (see:\n"
              "http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html)，包含构建源文件时使用的选项。这等效于向\n"
              "clang 工具（如 clang-check）指定 -p 选项。然后这些选项将传递给解析器。使用 CLANG_OPTIONS 指定的任何选项也将被添加。\n"
              "注意： 此选项的可用性取决于 Doxygen 是否使用 CMake 的 -Duse_libclang=ON 选项生成。"
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "如果 ALPHABETICAL_INDEX 标签设置为 YES ，将生成所有复合类型的字母索引。如果项目包含大量类、结构体、联合体或接口，请启用此选项。\n"
              "默认值为： YES。"
          );
  doc->add(
              "IGNORE_PREFIX",
              "IGNORE_PREFIX 标签可用于指定在生成索引标题时应忽略的前缀（或前缀列表）。 IGNORE_PREFIX\n"
              "标签适用于类、函数和成员名称。实体将放置在移除前缀后实体名称的首字母下的字母列表中。\n"
              "此标签要求标签 ALPHABETICAL_INDEX 设置为YES。"
          );
  doc->add(
              "GENERATE_HTML",
              "如果 GENERATE_HTML 标签设置为 YES ，Doxygen 将生成 HTML 输出\n"
              "默认值为： YES。"
          );
  doc->add(
              "HTML_OUTPUT",
              "HTML_OUTPUT 标签用于指定 HTML 文档的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：html。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "HTML_FILE_EXTENSION 标签可用于指定每个生成的 HTML 页面的文件扩展名（例如： .htm, .php, .asp）。\n"
              "默认值为： .html。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_HEADER",
              "HTML_HEADER 标签可用于为每个生成的 HTML 页面指定用户定义的 HTML 头文件。如果标签留空，Doxygen 将生成标准头文件。\n"
              "\n"
              "要获得有效的 HTML，头文件需要包含 Doxygen 需要的任何脚本和样式表，这取决于使用的配置选项（例如设置\n"
              "GENERATE_TREEVIEW）。强烈建议使用默认头文件开始：\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "然后修改文件 new_header.html 。另请参阅第 \"Doxygen usage\" 节以获取有关如何生成 Doxygen\n"
              "通常使用的默认头文件的信息。\n"
              "注意： 头文件可能会更改，因此通常在升级到更新版本的 Doxygen 时必须重新生成默认头文件。有关可用标记和代码块名称的说明，请参阅文档。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_FOOTER",
              "HTML_FOOTER 标签可用于为每个生成的 HTML 页面指定用户定义的 HTML 页脚。如果标签留空，Doxygen 将生成标准页脚。请参阅\n"
              "HTML_HEADER 以获取有关如何生成默认页脚以及页脚内可以使用哪些特殊命令的更多信息。另请参阅第 \"Doxygen usage\" 节以获取有关如何生成\n"
              "Doxygen 通常使用的默认页脚的信息。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_STYLESHEET",
              "HTML_STYLESHEET 标签可用于指定每个 HTML 页面使用的用户定义的级联样式表。它可用于微调 HTML 输出的外观。如果留空，Doxygen\n"
              "将生成默认样式表。另请参阅第 \"Doxygen usage\" 节以获取有关如何生成 Doxygen 通常使用的样式表的信息。\n"
              "注意： 建议使用 HTML_EXTRA_STYLESHEET 而不是此标签，因为它更健壮，并且此标签（HTML_STYLESHEET）将来会过时。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "HTML_EXTRA_STYLESHEET 标签可用于指定在 Doxygen\n"
              "创建的标准样式表之后包含的其他用户定义的级联样式表。使用此选项可以覆盖某些样式方面。这比使用 HTML_STYLESHEET\n"
              "更可取，因为它不会替换标准样式表，因此对未来的更新更加健壮。Doxygen 会将样式表文件复制到输出目录。\n"
              "注意： 额外样式表文件的顺序很重要（例如，列表中的最后一个样式表覆盖列表中前一个样式表的设置）。\n"
              "注意： 由于目前无法在 Webkit/Chromium 中覆盖滚动条的样式，如果指定了一个或多个额外样式表，默认 doxygen.css\n"
              "中将省略滚动条样式。因此，如果需要自定义滚动条，必须显式添加。例如，请参阅文档。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "HTML_EXTRA_FILES 标签可用于指定一个或多个应复制到 HTML 输出目录的额外图像或其他源文件。请注意，这些文件将被复制到基本 HTML\n"
              "输出目录。使用 HTML_HEADER 和/或 HTML_FOOTER 文件中的 $relpath^ 标记来加载这些文件。在 HTML_STYLESHEET\n"
              "文件中，仅使用文件名。另请注意，文件将按原样复制；没有可用的命令或标记。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_COLORSTYLE",
              "HTML_COLORSTYLE 标签可用于指定生成的 HTML 输出是否应以深色或浅色主题呈现。\n"
              "可能的值有：LIGHT 始终生成浅色模式输出, DARK 始终生成深色模式输出, AUTO_LIGHT\n"
              "根据用户偏好自动设置模式，如果未设置偏好则使用浅色模式（默认）, AUTO_DARK 根据用户偏好自动设置模式，如果未设置偏好则使用深色模式和TOGGLE\n"
              "允许用户通过按钮在浅色和深色模式之间切换.\n"
              "默认值为： AUTO_LIGHT。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "HTML_COLORSTYLE_HUE 标签控制 HTML 输出的颜色。Doxygen\n"
              "将根据此颜色调整样式表和背景图像中的颜色。色调指定为色环上的角度，请参阅 https://en.wikipedia.org/wiki/Hue\n"
              "以获取更多信息。例如，值 0 表示红色，60 是黄色，120 是绿色，180 是青色，240 是蓝色，300 是紫色，360 又是红色。\n"
              "最小值：0，最大值：359，默认值：220。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "HTML_COLORSTYLE_SAT 标签控制 HTML 输出中颜色的纯度（或饱和度）。值为 0 时，输出将仅使用灰度。值为 255\n"
              "将产生最鲜艳的颜色。\n"
              "最小值：0，最大值：255，默认值：100。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "HTML_COLORSTYLE_GAMMA 标签控制应用于 HTML 输出中颜色亮度分量的伽马校正。低于 100 的值逐渐使输出变亮，而高于 100\n"
              "的值使输出变暗。该值除以 100 是实际应用的伽马值，因此 80 表示伽马为 0.8，值 220 表示伽马为 2.2，100 不改变伽马。\n"
              "最小值：40，最大值：240，默认值：80。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "如果 HTML_DYNAMIC_MENUS 标签设置为 YES ，则生成的 HTML 文档将包含一个主索引，其中包含通过 JavaScript\n"
              "动态创建的垂直导航菜单。如果禁用，导航索引将由静态嵌入每个 HTML 页面的多级选项卡组成。禁用此选项以支持没有 JavaScript 的浏览器，如 Qt\n"
              "帮助浏览器。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "如果 HTML_DYNAMIC_SECTIONS 标签设置为 YES ，则生成的 HTML 文档将包含在页面加载后可以隐藏和显示的部分。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "如果 HTML_CODE_FOLDING 标签设置为 YES ，则类和函数可以在生成的 HTML 源代码中动态折叠和展开。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "如果 HTML_COPY_CLIPBOARD 标签设置为 YES ，Doxygen\n"
              "将在代码和文本片段的右上角显示一个图标，允许用户将其内容复制到剪贴板。请注意，这仅在浏览器支持且网页通过安全上下文 (see:\n"
              "https://www.w3.org/TR/secure-contexts/)提供服务时才有效，即使用 https: 或 file: 协议。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen 在浏览器中持久存储一些设置（例如通过 cookie）。默认情况下，这些设置适用于 Doxygen 在所有项目中生成的所有 HTML 页面。\n"
              "HTML_PROJECT_COOKIE 标签可用于在项目特定的键下存储设置，以便用户首选项将单独存储。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "使用 HTML_INDEX_NUM_ENTRIES 可以控制最初在各种树结构索引中显示的首选条目数；用户稍后可以动态展开和折叠条目。Doxygen\n"
              "将树展开到最多可见指定数量条目的级别（除非完全折叠的树已经超过此数量）。因此，将条目数设置为 1 将默认生成完全折叠的树。0\n"
              "是一个特殊值，表示无限数量的条目，将导致默认生成完全展开的树。\n"
              "最小值：0，最大值：9999，默认值：100。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "GENERATE_DOCSET",
              "如果 GENERATE_DOCSET 标签设置为 YES ，将生成额外的索引文件，可用作 OSX 10.5 (Leopard) 引入的 Apple 的\n"
              "Xcode 3 集成开发环境 (see:\n"
              "https://developer.apple.com/xcode/)的输入。要创建文档集，Doxygen 将在 HTML 输出目录中生成\n"
              "Makefile。运行 make 将在该目录中生成 docset，运行 make install 将把 docset 安装在\n"
              "~/Library/Developer/Shared/Documentation/DocSets 中，以便 Xcode 在启动时找到它。请参阅 https:\n"
              "//developer.apple.com/library/archive/featuredarticles/DoxygenXcode/_index.htm\n"
              "l 以获取更多信息。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "此标签确定 docset 订阅源的名称。文档订阅源提供了一个保护伞，可以将来自单个提供商（如公司或产品套件）的多个文档集分组。\n"
              "默认值为： Doxygen generated docs。\n"
              "此标签要求标签 GENERATE_DOCSET 设置为YES。"
          );
  doc->add(
              "DOCSET_FEEDURL",
              "此标签确定 docset 订阅源的 URL。文档订阅源提供了一个保护伞，可以将来自单个提供商（如公司或产品套件）的多个文档集分组。\n"
              "此标签要求标签 GENERATE_DOCSET 设置为YES。"
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "此标签指定一个应唯一标识文档集包的字符串。这应该是反向域名样式的字符串，例如 com.mycompany.MyDocSet。Doxygen 会将\n"
              ".docset 附加到名称后。\n"
              "默认值为： org.doxygen.Project。\n"
              "此标签要求标签 GENERATE_DOCSET 设置为YES。"
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "DOCSET_PUBLISHER_ID 标签指定一个应唯一标识文档发布者的字符串。这应该是反向域名样式的字符串，例如\n"
              "com.mycompany.MyDocSet.documentation。\n"
              "默认值为： org.doxygen.Publisher。\n"
              "此标签要求标签 GENERATE_DOCSET 设置为YES。"
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "DOCSET_PUBLISHER_NAME 标签标识文档发布者。\n"
              "默认值为： Publisher。\n"
              "此标签要求标签 GENERATE_DOCSET 设置为YES。"
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "如果 GENERATE_HTMLHELP 标签设置为 YES ，Doxygen 会生成三个额外的 HTML 索引文件： index.hhp 、\n"
              "index.hhc 和 index.hhk 。 index.hhp 是一个项目文件，可以由 Windows 上的 Microsoft HTML Help\n"
              "Workshop 读取。2021 年初，Microsoft 将原始页面（包括下载链接）下线（HTML 帮助工作室已经处于维护模式多年）。您可以从网络档案下载\n"
              "HTML 帮助工作室，网址为 安装可执行文件 (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe)。\n"
              "\n"
              "HTML Help Workshop 包含一个编译器，可以将 Doxygen 生成的所有 HTML 输出转换为单个编译的 HTML 文件（\n"
              ".chm）。编译的 HTML 文件现在用作 Windows 98 帮助格式，将来将在所有 Windows 平台上替换旧的 Windows 帮助格式（\n"
              ".hlp）。压缩的 HTML 文件还包含索引、目录，您可以在文档中搜索单词。HTML 工作室还包含一个用于压缩 HTML 文件的查看器。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "CHM_FILE",
              "CHM_FILE 标签可用于指定生成的 .chm 文件的文件名。如果结果不应写入 html 输出目录，可以在文件前添加路径。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "HHC_LOCATION",
              "HHC_LOCATION 标签可用于指定 HTML 帮助编译器（ hhc.exe ）的位置（包含文件名的绝对路径）。如果非空，Doxygen\n"
              "将尝试在生成的 index.hhp 上运行 HTML 帮助编译器。\n"
              "文件必须使用完整路径指定。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "GENERATE_CHI",
              "GENERATE_CHI 标志控制是否生成单独的 .chi 索引文件（ YES ）或将其包含在主 .chm 文件中（ NO ）。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "CHM_INDEX_ENCODING 用于编码 HtmlHelp 索引（ hhk ）、内容（ hhc ）和项目文件内容。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "BINARY_TOC",
              "BINARY_TOC 标志控制 .chm 文件中是生成二进制目录（ YES ）还是普通目录（ NO ）。此外，它启用 Previous 和 Next\n"
              "按钮。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "TOC_EXPAND",
              "TOC_EXPAND 标志可以设置为 YES ，以便为组成员向 HTML 帮助文档的目录和树视图添加额外项目。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTMLHELP 设置为YES。"
          );
  doc->add(
              "SITEMAP_URL",
              "SITEMAP_URL 标签用于指定用户在文档部署期间将生成的文档放置在服务器上的位置的完整 URL。生成的站点地图称为 sitemap.xml，放置在\n"
              "HTML_OUTPUT 指定的目录中。如果未指定 SITEMAP_URL ，则不会生成站点地图。有关站点地图协议的信息，请参阅\n"
              "https://www.sitemaps.org\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "GENERATE_QHP",
              "如果 GENERATE_QHP 标签设置为 YES 且 QHP_NAMESPACE 和 QHP_VIRTUAL_FOLDER\n"
              "都已设置，将生成额外的索引文件，可用作 Qt 的 qhelpgenerator 的输入，以生成生成 HTML 文档的 Qt 压缩帮助（ .qch）。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "QCH_FILE",
              "如果指定了 QHG_LOCATION 标签， QCH_FILE 标签可用于指定生成的 .qch 文件的文件名。指定的路径相对于 HTML 输出文件夹。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHP_NAMESPACE",
              "QHP_NAMESPACE 标签指定生成 Qt 帮助项目输出时使用的命名空间。有关更多信息，请参阅 Qt 帮助项目 / 命名空间 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace)。\n"
              "默认值为： org.doxygen.Project。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "QHP_VIRTUAL_FOLDER 标签指定生成 Qt 帮助项目输出时使用的命名空间。有关更多信息，请参阅 Qt 帮助项目 / 虚拟文件夹 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders)。\n"
              "默认值为： doc。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "如果设置了 QHP_CUST_FILTER_NAME 标签，它指定要添加的自定义过滤器的名称。有关更多信息，请参阅 Qt 帮助项目 / 自定义过滤器\n"
              "(see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "QHP_CUST_FILTER_ATTRS 标签指定要添加的自定义过滤器的属性列表。有关更多信息，请参阅 Qt 帮助项目 / 自定义过滤器 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "QHP_SECT_FILTER_ATTRS 标签指定此项目的过滤器部分匹配的属性列表。Qt 帮助项目 / 过滤器属性 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes)。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "QHG_LOCATION",
              "QHG_LOCATION 标签可用于指定 Qt 的 qhelpgenerator 的位置（包含文件名的绝对路径）。如果非空，Doxygen 将尝试在生成的\n"
              ".qhp 文件上运行 qhelpgenerator。\n"
              "此标签要求标签 GENERATE_QHP 设置为YES。"
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "如果 GENERATE_ECLIPSEHELP 标签设置为 YES ，将生成额外的索引文件，与 HTML 文件一起，它们形成一个 Eclipse\n"
              "帮助插件。要安装此插件并使其在 Eclipse 的帮助内容菜单下可用，需要将包含 HTML 和 XML 文件的目录的内容复制到 eclipse\n"
              "的插件目录中。插件目录中的目录名称应与 ECLIPSE_DOC_ID 值相同。复制后，Eclipse 需要重新启动才能显示帮助。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Eclipse 帮助插件的唯一标识符。安装插件时，包含 HTML 和 XML 文件的目录名称也应具有此名称。每个文档集应具有自己的标识符。\n"
              "默认值为： org.doxygen.Project。\n"
              "此标签要求标签 GENERATE_ECLIPSEHELP 设置为YES。"
          );
  doc->add(
              "DISABLE_INDEX",
              "如果您想完全控制生成的 HTML 页面的布局，可能需要禁用索引并用您自己的索引替换它。 DISABLE_INDEX 标签可用于打开/关闭每个 HTML\n"
              "页面顶部的压缩索引（选项卡）。值为 NO 启用索引，值 YES 禁用它。由于索引中的选项卡包含与导航树相同的信息，如果您还将\n"
              "GENERATE_TREEVIEW 设置为 YES ，则可以将此选项设置为 YES 。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "GENERATE_TREEVIEW 标签用于指定是否应生成树状索引结构以显示层次信息。如果标签值设置为 YES\n"
              "，将生成一个包含树状索引结构的侧面板（就像为 HTML 帮助生成的结构一样）。为此，需要一个支持 JavaScript、DHTML、CSS\n"
              "和框架的浏览器（即任何现代浏览器）。Windows 用户可能最好使用 HTML 帮助功能。通过自定义样式表（请参阅\n"
              "HTML_EXTRA_STYLESHEET），可以进一步微调索引的外观（请参阅 \"Fine-tuning the output\" ）。例如，Doxygen\n"
              "生成的默认样式表有一个示例，显示如何在树的根部放置图像而不是 PROJECT_NAME。由于树基本上比选项卡索引具有更多详细信息，您可以考虑在启用此选项时将\n"
              "DISABLE_INDEX 设置为 YES 。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "当 GENERATE_TREEVIEW 设置为 YES 时， PAGE_OUTLINE_PANEL\n"
              "选项确定是否在屏幕右侧显示一个额外的导航面板，显示主页面的内容大纲，类似于例如\n"
              "https://developer.android.com/reference。如果 GENERATE_TREEVIEW 设置为 NO ，此选项无效。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "FULL_SIDEBAR",
              "当 GENERATE_TREEVIEW 设置为 YES 时， FULL_SIDEBAR 选项确定侧边栏是否仅限于树视图区域（值 NO\n"
              "）还是应该延伸到窗口的整个高度（值 YES ）。将此设置为 YES 会产生类似于例如 https://docs.readthedocs.io\n"
              "的布局，内容空间更大，但项目徽标、标题和描述的空间更小。如果 GENERATE_TREEVIEW 设置为 NO ，此选项无效。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "ENUM_VALUES_PER_LINE 标签可用于设置 Doxygen 在生成的 HTML 文档中每行分组的枚举值数量。\n"
              "\n"
              "请注意，值为 0 将完全抑制枚举值出现在概述部分中。\n"
              "最小值：0，最大值：20，默认值：4。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "当设置 SHOW_ENUM_VALUES 标签时，Doxygen 将在枚举助记符旁边显示指定的枚举值。\n"
              "默认值为： NO。"
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "如果启用了树视图（请参阅 GENERATE_TREEVIEW），则此标签可用于设置显示树的框架的初始宽度（以像素为单位）。\n"
              "最小值：0，最大值：1500，默认值：250。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "如果 EXT_LINKS_IN_WINDOW 选项设置为 YES ，Doxygen 将在单独的窗口中打开通过标签文件导入的外部符号的链接。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "如果 OBFUSCATE_EMAILS 标签设置为 YES ，Doxygen 将混淆电子邮件地址。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "如果 HTML_FORMULA_FORMAT 选项设置为 svg ，Doxygen 将使用 pdf2svg 工具（请参阅\n"
              "https://github.com/dawbarton/pdf2svg）或 inkscape（请参阅 https://inkscape.org）为\n"
              "HTML 输出生成 SVG 图像而不是 PNG。这些图像在缩放分辨率下通常看起来更好。\n"
              "可能的值有：png （默认）和svg （看起来更好，但需要pdf2svg或inkscape工具）.\n"
              "默认值为： png。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "使用此标签更改包含在 HTML 文档中作为图像的 LaTeX 公式的字体大小。在成功运行 Doxygen 后更改字体大小时，您需要手动从 HTML\n"
              "输出目录中删除任何 form_*.png 图像以强制重新生成它们。\n"
              "最小值：8，最大值：50，默认值：10。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "FORMULA_MACROFILE",
              "FORMULA_MACROFILE 可以包含 LaTeX \\newcommand 和 \\renewcommand 命令，以创建新的 LaTeX\n"
              "命令，用作公式中的构建块。有关详细信息，请参阅第 \"Including formulas\" 节。"
          );
  doc->add(
              "USE_MATHJAX",
              "启用 USE_MATHJAX 选项以使用 MathJax（请参阅 https://www.mathjax.org）呈现 LaTeX 公式，它使用客户端\n"
              "JavaScript 进行呈现，而不是使用预呈现的位图。如果您没有安装 LaTeX 或者您希望公式在 HTML\n"
              "输出中看起来更漂亮，请使用此选项。启用后，您可能还需要单独安装 MathJax 并使用 MATHJAX_RELPATH 选项配置其路径。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "MATHJAX_VERSION",
              "使用 MATHJAX_VERSION 可以指定要使用的 MathJax 版本。请注意，不同版本的 MathJax 对不同设置有不同的要求，因此在不同的\n"
              "MathJax 版本之间切换时，可能还需要更改其他 MathJax 设置。\n"
              "可能的值有：MathJax_2, MathJax_3和MathJax_4.\n"
              "默认值为： MathJax_2。\n"
              "此标签要求标签 USE_MATHJAX 设置为YES。"
          );
  doc->add(
              "MATHJAX_FORMAT",
              "启用 MathJax 后，您可以设置 MathJax 输出使用的默认输出格式。有关输出格式的更多详细信息，请参阅 MathJax 版本 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html)、MathJax 版本 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) 和 MathJax 版本 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm)。\n"
              "可能的值有：HTML-CSS （较慢，但兼容性最好。这是MathJax版本2的名称，对于MathJax版本3将被转换为 chtml ）, NativeMML\n"
              "（即MathML。仅MathJax 2支持。对于MathJax版本3将使用 chtml 代替。）, chtml\n"
              "（这是MathJax版本3的名称，对于MathJax版本2将被转换为HTML-CSS）和SVG.\n"
              "默认值为： HTML-CSS。\n"
              "此标签要求标签 USE_MATHJAX 设置为YES。"
          );
  doc->add(
              "MATHJAX_RELPATH",
              "当启用 MathJax 时，您需要使用 MATHJAX_RELPATH 选项指定相对于 HTML 输出目录的位置。 对于 MathJax 版本\n"
              "2，目标目录应包含 MathJax.js 脚本。例如，如果 mathjax 目录 与 HTML 输出目录位于同一级别，则 MATHJAX_RELPATH\n"
              "应为 ../mathjax。 对于 MathJax 版本 3 和 4，目标目录应包含 tex-<format>.js 脚本（其中 <format> 为\n"
              "chtml 或 svg）。默认值指向 MathJax 内容分发网络，以便您无需安装 MathJax 即可快速查看结果。但是，强烈建议在部署前从\n"
              "https://www.mathjax.org 安装 MathJax 的本地副本。 默认值为：\n"
              "- MathJax 版本 2 的情况: https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- MathJax 版本 3 的情况: https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- MathJax 版本 4 的情况: https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "此标签要求标签 USE_MATHJAX 设置为YES。"
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "MATHJAX_EXTENSIONS 标签可用于指定在 MathJax 呈现期间应启用的一个或多个 MathJax 扩展名称。例如，对于 MathJax\n"
              "版本 2（请参阅 https://docs.mathjax.org/en/v2.7/tex.html）：\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "例如，对于 MathJax 版本 3（请参阅\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/）：\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "例如，对于 MathJax 版本 4（请参阅\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/）：\n"
              "MATHJAX_EXTENSIONS = units\n"
              "请注意，对于 Mathjax 版本 4，已经自动加载了相当多的扩展。要在 Mathjax 版本 4 中禁用包，可以使用前面带有减号的包名称（- 如\n"
              "MATHJAX_EXTENSIONS += -textmacros）\n"
              "此标签要求标签 USE_MATHJAX 设置为YES。"
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "MATHJAX_CODEFILE 标签可用于指定一个包含 JavaScript 代码片段的文件，这些代码将在 MathJax\n"
              "代码启动时使用。有关更多详细信息，请参阅 Mathjax 网站：\n"
              "- MathJax 版本 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax 版本 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax 版本 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)例如，请参阅文档。\n"
              "此标签要求标签 USE_MATHJAX 设置为YES。"
          );
  doc->add(
              "SEARCHENGINE",
              "当 SEARCHENGINE 标签启用时，Doxygen 将为 HTML 输出生成一个搜索框。底层搜索引擎使用 JavaScript 和\n"
              "DHTML，应该可以在任何现代浏览器上运行。请注意，当使用 HTML 帮助（GENERATE_HTMLHELP）、Qt\n"
              "帮助（GENERATE_QHP）或文档集（GENERATE_DOCSET）时，已经有搜索功能，因此通常应禁用此功能。对于大型项目，基于 JavaScript\n"
              "的搜索引擎可能很慢，然后启用 SERVER_BASED_SEARCH 可能提供更好的解决方案。可以使用键盘进行搜索；要跳转到搜索框，请使用 <access\n"
              "key> + S（<access key> 取决于操作系统和浏览器，但通常是 <CTRL>、<ALT>/<option> 或两者）。在搜索框内，使用\n"
              "<cursor down key> 跳转到搜索结果窗口，可以使用 <cursor keys> 导航结果。按 <Enter> 选择项目或 <escape>\n"
              "取消搜索。当光标在搜索框内时，可以通过按 <Shift>+<cursor down> 选择过滤器选项。在这里也使用 <cursor keys>\n"
              "选择过滤器，使用 <Enter> 或 <escape> 激活或取消过滤器选项。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_HTML 设置为YES。"
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "当 SERVER_BASED_SEARCH 标签启用时，搜索引擎将使用 Web 服务器而不是使用 JavaScript 的 Web 客户端来实现。根据\n"
              "EXTERNAL_SEARCH 设置，有两种风格的基于 Web 服务器的搜索。禁用时，Doxygen 将生成用于搜索的 PHP\n"
              "脚本和脚本使用的索引文件。当启用 EXTERNAL_SEARCH 时，需要由外部工具提供索引和搜索。有关详细信息，请参阅第 \"External\n"
              "Indexing and Searching\" 节。\n"
              "默认值为： NO。\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "当 EXTERNAL_SEARCH 标签启用时，Doxygen 将不再生成用于搜索的 PHP 脚本。相反，搜索结果将写入 XML\n"
              "文件，需要由外部索引器处理。Doxygen 将调用 SEARCHENGINE_URL 选项指向的外部搜索引擎以获取搜索结果。\n"
              "\n"
              "Doxygen 附带一个示例索引器（ doxyindexer ）和搜索引擎（doxysearch.cgi），它们基于开源搜索引擎库 Xapian (see:\n"
              "https://xapian.org/)。\n"
              "\n"
              "有关详细信息，请参阅第 \"External Indexing and Searching\" 节。\n"
              "默认值为： NO。\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "SEARCHENGINE_URL",
              "SEARCHENGINE_URL 应指向由 Web 服务器托管的搜索引擎，当启用 EXTERNAL_SEARCH 时将返回搜索结果。\n"
              "\n"
              "Doxygen 附带一个示例索引器（ doxyindexer ）和搜索引擎（doxysearch.cgi），它们基于开源搜索引擎库 Xapian (see:\n"
              "https://xapian.org/)。有关详细信息，请参阅第 \"External Indexing and Searching\" 节。\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "SEARCHDATA_FILE",
              "当 SERVER_BASED_SEARCH 和 EXTERNAL_SEARCH 都启用时，未索引的搜索数据将写入文件以供外部工具索引。使用\n"
              "SEARCHDATA_FILE 标签可以指定此文件的名称。\n"
              "默认文件为：searchdata.xml。\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "当 SERVER_BASED_SEARCH 和 EXTERNAL_SEARCH 都启用时， EXTERNAL_SEARCH_ID\n"
              "标签可用作项目的标识符。这与 EXTRA_SEARCH_MAPPINGS 结合使用很有用，可以搜索多个项目并将结果重定向回正确的项目。\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "EXTRA_SEARCH_MAPPINGS 标签可用于启用搜索除此配置文件定义的项目以外的 Doxygen\n"
              "项目，但这些项目都添加到同一外部搜索索引中。每个项目需要通过 EXTERNAL_SEARCH_ID 设置唯一的 id。然后搜索映射将 id\n"
              "映射到可以找到文档的相对位置。格式为：\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "此标签要求标签 SEARCHENGINE 设置为YES。"
          );
  doc->add(
              "GENERATE_LATEX",
              "如果 GENERATE_LATEX 标签设置为 YES ，Doxygen 将生成 LaTeX 输出。\n"
              "默认值为： YES。"
          );
  doc->add(
              "LATEX_OUTPUT",
              "LATEX_OUTPUT 标签用于指定 LaTeX 文档的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：latex。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_CMD_NAME",
              "LATEX_CMD_NAME 标签可用于指定要调用的 LaTeX 命令名称。\n"
              "\n"
              "请注意，当不启用 USE_PDFLATEX 时，默认值为 latex ；当启用 USE_PDFLATEX 时，默认值为 pdflatex\n"
              "；在后一种情况下，如果选择 latex ，则会被 pdflatex 覆盖。对于特定的输出语言，默认值可能已设置为不同的值，这取决于输出语言的实现。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "MAKEINDEX_CMD_NAME 标签可用于指定为 LaTeX 生成索引的命令名称。\n"
              "注意： 此标签在 Makefile / make.bat 中使用。\n"
              "另请参阅： LATEX_MAKEINDEX_CMD 用于生成输出文件（ .tex）中的部分。\n"
              "默认文件为：makeindex。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "LATEX_MAKEINDEX_CMD 标签可用于指定为 LaTeX 生成索引的命令名称。如果第一个字符没有反斜杠（ \\ ），则会自动添加到 LaTeX\n"
              "代码中。\n"
              "注意： 此标签在生成输出文件（ .tex）中使用。\n"
              "另请参阅： MAKEINDEX_CMD_NAME 用于 Makefile / make.bat 中的部分。\n"
              "默认值为： makeindex。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "COMPACT_LATEX",
              "如果 COMPACT_LATEX 标签设置为 YES ，Doxygen 会生成更紧凑的 LaTeX\n"
              "文档。这对于小型项目可能很有用，通常可能有助于节省一些树木。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "PAPER_TYPE",
              "PAPER_TYPE 标签可用于设置打印机使用的纸张类型。\n"
              "可能的值有：a4 （210 x 297 毫米）, letter （8.5 x 11 英寸）, legal （8.5 x 14 英寸）和executive\n"
              "（7.25 x 10.5 英寸）.\n"
              "默认值为： a4。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "EXTRA_PACKAGES",
              "EXTRA_PACKAGES 标签可用于指定应包含在 LaTeX 输出中的一个或多个 LaTeX 包名称。可以仅通过名称或使用与 LaTeX\n"
              "\\usepackage 命令一起使用的正确语法来指定包。例如，要获取 times 字体，您可以指定：\n"
              "EXTRA_PACKAGES=times 或 EXTRA_PACKAGES={times}\n"
              "要将选项 intlimits 与 amsmath 包一起使用，您可以指定：\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "如果留空，则不包含额外的包。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_HEADER",
              "LATEX_HEADER 标签可用于为生成的 LaTeX 文档指定用户定义的 LaTeX\n"
              "头文件。头文件应包含直到第一章的所有内容。如果留空，Doxygen 将生成标准头文件。强烈建议使用默认头文件开始：\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "然后修改文件 new_header.tex 。另请参阅第 \"Doxygen usage\" 节以获取有关如何生成 Doxygen\n"
              "通常使用的默认头文件的信息。\n"
              "\n"
              "注意：只有在您知道自己在做什么时才使用用户定义的头文件！\n"
              "注意： 头文件可能会更改，因此通常在升级到更新版本的 Doxygen 时必须重新生成默认头文件。有关可用标记和代码块名称的说明，请参阅文档。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_FOOTER",
              "LATEX_FOOTER 标签可用于为生成的 LaTeX 文档指定用户定义的 LaTeX 页脚。页脚应包含最后一章之后的所有内容。如果留空，Doxygen\n"
              "将生成标准页脚。请参阅 LATEX_HEADER 以获取有关如何生成默认页脚以及页脚内可以使用哪些特殊命令的更多信息。另请参阅第 \"Doxygen\n"
              "usage\" 节以获取有关如何生成 Doxygen 通常使用的默认页脚的信息。注意：只有在您知道自己在做什么时才使用用户定义的页脚！\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "LATEX_EXTRA_STYLESHEET 标签可用于指定在 Doxygen 创建的标准样式表之后包含的其他用户定义的 LaTeX\n"
              "样式表。使用此选项可以覆盖某些样式方面。Doxygen 会将样式表文件复制到输出目录。\n"
              "注意： 额外样式表文件的顺序很重要（例如，列表中的最后一个样式表覆盖列表中前一个样式表的设置）。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "LATEX_EXTRA_FILES 标签可用于指定一个或多个应复制到 LATEX_OUTPUT\n"
              "输出目录的额外图像或其他源文件。请注意，文件将按原样复制；没有可用的命令或标记。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "PDF_HYPERLINKS",
              "如果 PDF_HYPERLINKS 标签设置为 YES ，生成的 LaTeX 将准备转换为 PDF（使用 ps2pdf 或 pdflatex ）。PDF\n"
              "文件将包含链接（就像 HTML 输出一样）而不是页面引用。这使得输出适合使用 PDF 查看器进行在线浏览。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "USE_PDFLATEX",
              "如果 USE_PDFLATEX 标签设置为 YES ，Doxygen 将使用 LATEX_CMD_NAME 指定的引擎直接从 LaTeX 文件生成 PDF\n"
              "文件。将此选项设置为 YES 以获得更高质量的 PDF 文档。\n"
              "\n"
              "另请参阅第 LATEX_CMD_NAME 节以选择引擎。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_BATCHMODE",
              "LATEX_BATCHMODE 标签指示 LaTeX 在出现错误时的行为。\n"
              "可能的值有：NO 与ERROR_STOP相同, YES 与BATCH相同, BATCH 在批处理模式下，终端不打印任何内容，错误会像在每个错误处按下<ret\n"
              "urn>一样滚动；TeX尝试输入或从键盘输入请求的缺失文件（在未打开的输入流上的\\read）会导致作业中止, NON_STOP\n"
              "在非停止模式下，诊断消息将显示在终端上，但像批处理模式一样无法进行用户交互, SCROLL\n"
              "在滚动模式下，TeX仅在缺少输入文件或需要键盘输入时停止和ERROR_STOP 在错误停止模式下，TeX将在每个错误处停止，请求用户干预.\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "如果 LATEX_HIDE_INDICES 标签设置为 YES ，Doxygen 将不在输出中包含索引章节（如文件索引、复合索引等）。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "LATEX_BIB_STYLE 标签可用于指定参考文献使用的样式，例如 plainnat 或 ieeetr 。请参阅\n"
              "https://en.wikipedia.org/wiki/BibTeX 和 \\cite 以获取更多信息。\n"
              "默认值为： plainnat。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "LATEX_EMOJI_DIRECTORY 标签用于指定读取 emoji 图像的（相对或绝对）路径。如果输入相对路径，它将相对于 LATEX_OUTPUT\n"
              "目录。如果留空，则使用 LATEX_OUTPUT 目录。\n"
              "此标签要求标签 GENERATE_LATEX 设置为YES。"
          );
  doc->add(
              "GENERATE_RTF",
              "如果 GENERATE_RTF 标签设置为 YES ，Doxygen 将生成 RTF 输出。RTF 输出针对 Word 97 进行了优化，在其他 RTF\n"
              "阅读器/编辑器中可能看起来不太漂亮。\n"
              "默认值为： NO。"
          );
  doc->add(
              "RTF_OUTPUT",
              "RTF_OUTPUT 标签用于指定 RTF 文档的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：rtf。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "COMPACT_RTF",
              "如果 COMPACT_RTF 标签设置为 YES ，Doxygen 会生成更紧凑的 RTF 文档。这对于小型项目可能很有用，通常可能有助于节省一些树木。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "RTF_HYPERLINKS",
              "如果 RTF_HYPERLINKS 标签设置为 YES ，生成的 RTF 将包含超链接字段。RTF 文件将包含链接（就像 HTML\n"
              "输出一样）而不是页面引用。这使得输出适合使用 Word 或其他支持这些字段的 Word 兼容阅读器进行在线浏览。\n"
              "\n"
              "注意：写字板（write）和其他程序不支持链接。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "从文件加载样式表定义。语法类似于 Doxygen 的配置文件，即一系列赋值。您只需要提供替换，缺少的定义设置为其默认值。\n"
              "\n"
              "另请参阅第 \"Doxygen usage\" 节以获取有关如何生成 Doxygen 通常使用的默认样式表的信息。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "设置生成 RTF 文档时使用的可选变量。语法类似于 Doxygen 的配置文件。可以使用 doxygen -e rtf extensionFile\n"
              "生成模板扩展文件。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "RTF_EXTRA_FILES 标签可用于指定一个或多个应复制到 RTF_OUTPUT\n"
              "输出目录的额外图像或其他源文件。请注意，文件将按原样复制；没有可用的命令或标记。\n"
              "此标签要求标签 GENERATE_RTF 设置为YES。"
          );
  doc->add(
              "GENERATE_MAN",
              "如果 GENERATE_MAN 标签设置为 YES ，Doxygen 将为类和文件生成 man 页面。\n"
              "默认值为： NO。"
          );
  doc->add(
              "MAN_OUTPUT",
              "MAN_OUTPUT 标签用于指定 man 页面的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。将在\n"
              "MAN_OUTPUT 指定的目录内创建一个 man3 目录。\n"
              "默认目录为：man。\n"
              "此标签要求标签 GENERATE_MAN 设置为YES。"
          );
  doc->add(
              "MAN_EXTENSION",
              "MAN_EXTENSION 标签确定添加到生成的 man 页面的扩展名。如果手册部分不以数字开头，则在前面加上数字 3。 MAN_EXTENSION\n"
              "标签开头的点（.）是可选的。\n"
              "默认值为： .3。\n"
              "此标签要求标签 GENERATE_MAN 设置为YES。"
          );
  doc->add(
              "MAN_SUBDIR",
              "MAN_SUBDIR 标签确定在 MAN_OUTPUT 中创建的放置 man 页面的目录名称。默认为 man 后跟 MAN_EXTENSION\n"
              "，并移除初始 .。\n"
              "此标签要求标签 GENERATE_MAN 设置为YES。"
          );
  doc->add(
              "MAN_LINKS",
              "如果 MAN_LINKS 标签设置为 YES 且 Doxygen 生成 man 输出，则它将为真实 man 页面中记录的每个实体生成一个额外的 man\n"
              "文件。这些额外的文件仅引用真实的 man 页面，但没有它们， man 命令将无法找到正确的页面。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_MAN 设置为YES。"
          );
  doc->add(
              "GENERATE_XML",
              "如果 GENERATE_XML 标签设置为 YES ，Doxygen 将生成一个捕获代码结构（包括所有文档）的 XML 文件。\n"
              "默认值为： NO。"
          );
  doc->add(
              "XML_OUTPUT",
              "XML_OUTPUT 标签用于指定 XML 页面的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：xml。\n"
              "此标签要求标签 GENERATE_XML 设置为YES。"
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "如果 XML_PROGRAMLISTING 标签设置为 YES ，Doxygen 将把程序列表（包括语法高亮和交叉引用信息）转储到 XML\n"
              "输出。请注意，启用此功能将显著增加 XML 输出的大小。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_XML 设置为YES。"
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "如果 XML_NS_MEMB_FILE_SCOPE 标签设置为 YES ，Doxygen 也会在文件作用域中包含命名空间成员，与 HTML 输出匹配。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_XML 设置为YES。"
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "如果 GENERATE_DOCBOOK 标签设置为 YES ，Doxygen 将生成可用于生成 PDF 的 Docbook 文件。\n"
              "默认值为： NO。"
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "DOCBOOK_OUTPUT 标签用于指定 Docbook 页面的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：docbook。\n"
              "此标签要求标签 GENERATE_DOCBOOK 设置为YES。"
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "如果 GENERATE_AUTOGEN_DEF 标签设置为 YES ，Doxygen 将生成一个捕获代码结构（包括所有文档）的 AutoGen 定义（请参阅\n"
              "https://autogen.sourceforge.net/）文件。请注意，此功能目前仍处于实验阶段且不完整。\n"
              "默认值为： NO。"
          );
  doc->add(
              "GENERATE_SQLITE3",
              "如果 GENERATE_SQLITE3 标签设置为 YES ，Doxygen 将生成一个 Sqlite3 数据库，其中包含 Doxygen\n"
              "找到的符号存储在表中。\n"
              "默认值为： NO。"
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "SQLITE3_OUTPUT 标签用于指定 Sqlite3 数据库的放置位置。如果输入相对路径，则 OUTPUT_DIRECTORY 的值将放在其前面。\n"
              "默认目录为：sqlite3。\n"
              "此标签要求标签 GENERATE_SQLITE3 设置为YES。"
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "如果 SQLITE3_RECREATE_DB 标签设置为 YES ，每次 Doxygen 运行时都会重新创建现有的 doxygen_sqlite3.db\n"
              "数据库文件。如果设置为 NO ，如果已经找到数据库文件，Doxygen 将发出警告并且不会修改它。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_SQLITE3 设置为YES。"
          );
  doc->add(
              "GENERATE_PERLMOD",
              "如果 GENERATE_PERLMOD 标签设置为 YES ，Doxygen 将生成一个捕获代码结构（包括所有文档）的 Perl 模块文件。\n"
              "\n"
              "请注意，此功能目前仍处于实验阶段且不完整。\n"
              "默认值为： NO。"
          );
  doc->add(
              "PERLMOD_LATEX",
              "如果 PERLMOD_LATEX 标签设置为 YES ，Doxygen 将生成必要的 Makefile 规则、 Perl 脚本和 LaTeX\n"
              "代码，以便能够从 Perl 模块输出生成 PDF 和 DVI 输出。\n"
              "默认值为： NO。\n"
              "此标签要求标签 GENERATE_PERLMOD 设置为YES。"
          );
  doc->add(
              "PERLMOD_PRETTY",
              "如果 PERLMOD_PRETTY 标签设置为 YES ，Perl\n"
              "模块输出将被很好地格式化，以便人类阅读器解析。如果您想了解发生了什么，这很有用。另一方面，如果此标签设置为 NO ，Perl\n"
              "模块输出的大小将小得多，Perl 也会同样解析它。\n"
              "默认值为： YES。\n"
              "此标签要求标签 GENERATE_PERLMOD 设置为YES。"
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "生成的 doxyrules.make 文件中的 make 变量名称以 PERLMOD_MAKEVAR_PREFIX 中包含的字符串为前缀。这很有用，因此同一\n"
              "Makefile 包含的不同 doxyrules.make 文件不会相互覆盖变量。\n"
              "此标签要求标签 GENERATE_PERLMOD 设置为YES。"
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "如果 ENABLE_PREPROCESSING 标签设置为 YES ，Doxygen 将评估源文件和包含文件中找到的所有 C 预处理指令。\n"
              "默认值为： YES。"
          );
  doc->add(
              "MACRO_EXPANSION",
              "如果 MACRO_EXPANSION 标签设置为 YES ，Doxygen 将展开源代码中的所有宏名称。如果设置为 NO ，则只执行条件编译。可以通过将\n"
              "EXPAND_ONLY_PREDEF 设置为 YES 以受控方式完成宏展开。\n"
              "默认值为： NO。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "如果 EXPAND_ONLY_PREDEF 和 MACRO_EXPANSION 标签都设置为 YES ，则宏展开仅限于使用 PREDEFINED 和\n"
              "EXPAND_AS_DEFINED 标签指定的宏。\n"
              "默认值为： NO。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "SEARCH_INCLUDES",
              "如果 SEARCH_INCLUDES 标签设置为 YES ，如果找到 #include ，则搜索 INCLUDE_PATH 中的包含文件。\n"
              "默认值为： YES。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "INCLUDE_PATH",
              "INCLUDE_PATH 标签可用于指定一个或多个包含不是输入文件但应由预处理器处理的包含文件的目录。请注意， INCLUDE_PATH 不是递归的，因此\n"
              "RECURSIVE 的设置在此无效。\n"
              "此标签要求标签 SEARCH_INCLUDES 设置为YES。"
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "您可以使用 INCLUDE_FILE_PATTERNS 标签指定一个或多个通配符模式（如 *.h 和 *.hpp）来过滤目录中的头文件。如果留空，则使用\n"
              "FILE_PATTERNS 指定的模式。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "PREDEFINED",
              "PREDEFINED 标签可用于指定在预处理器启动之前定义的一个或多个宏名称（类似于例如 gcc 的 -D 选项）。标签的参数是以下形式的宏列表：name\n"
              "或 name=definition（无空格）。如果省略定义和 \"=\" ，则假设为 \"=1\" 。要防止宏定义通过 #undef 取消定义或递归展开，请使用\n"
              ":= 运算符而不是 = 运算符。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "如果 MACRO_EXPANSION 和 EXPAND_ONLY_PREDEF 标签设置为 YES\n"
              "，则此标签可用于指定应展开的宏名称列表。将使用在源代码中找到的宏定义。如果您想使用覆盖源代码中找到的定义的不同宏定义，请使用 PREDEFINED 标签。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "如果 SKIP_FUNCTION_MACROS 标签设置为 YES ，Doxygen\n"
              "的预处理器将删除所有对单独一行、具有全大写名称且不以分号结尾的类函数宏的引用。此类函数宏通常用于样板代码，如果不删除，会使解析器混淆。\n"
              "默认值为： YES。\n"
              "此标签要求标签 ENABLE_PREPROCESSING 设置为YES。"
          );
  doc->add(
              "TAGFILES",
              "TAGFILES 标签可用于指定一个或多个标签文件。对于每个标签文件，应添加外部文档的位置。没有此位置的标签文件的格式如下：\n"
              "TAGFILES = file1 file2 ...\n"
              "为标签文件添加位置的方式如下：\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "其中 loc1 和 loc2 可以是相对或绝对路径或 URL。有关使用标签文件的更多信息，请参阅第 \"Linking to external\n"
              "documentation\" 节。\n"
              "注意： 每个标签文件必须具有唯一的名称（其中名称不包括路径）。如果标签文件不在运行 Doxygen 的目录中，您还必须在此处指定标签文件的路径。"
          );
  doc->add(
              "GENERATE_TAGFILE",
              "在 GENERATE_TAGFILE 后指定文件名时，Doxygen 将创建一个基于其读取的输入文件的标签文件。有关标签文件使用的更多信息，请参阅第\n"
              "\"Linking to external documentation\" 节。"
          );
  doc->add(
              "ALLEXTERNALS",
              "如果 ALLEXTERNALS 标签设置为 YES ，所有外部类和命名空间都将列在类和命名空间索引中。如果设置为 NO ，则只列出继承的外部类。\n"
              "默认值为： NO。"
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "如果 EXTERNAL_GROUPS 标签设置为 YES ，所有外部组都将列在主题索引中。如果设置为 NO ，则只列出当前项目的组。\n"
              "默认值为： YES。"
          );
  doc->add(
              "EXTERNAL_PAGES",
              "如果 EXTERNAL_PAGES 标签设置为 YES ，所有外部页面都将列在相关页面索引中。如果设置为 NO ，则只列出当前项目的页面。\n"
              "默认值为： YES。"
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "如果设置为 YES ，继承和协作图将隐藏目标未记录或不是类的继承和使用关系。\n"
              "默认值为： YES。"
          );
  doc->add(
              "HAVE_DOT",
              "如果将 HAVE_DOT 标签设置为 YES ，Doxygen 将假设 dot 工具可从 path 获得。此工具是 Graphviz (see:\n"
              "https://www.graphviz.org/) 的一部分，这是 AT&T 和 Lucent Bell Labs 的图形可视化工具包。如果此选项设置为\n"
              "NO ，本节中的其他选项无效\n"
              "默认值为： NO。"
          );
  doc->add(
              "DOT_NUM_THREADS",
              "DOT_NUM_THREADS 指定 Doxygen 允许并行运行的 dot 调用次数。设置为 0 时，Doxygen\n"
              "将根据系统中可用的处理器数量进行设置。您可以将其显式设置为大于 0 的值，以更好地控制 CPU 负载和处理速度之间的平衡。\n"
              "最小值：0，最大值：512，默认值：0。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "DOT_BATCH_SIZE 指定 Doxygen 在单次 dot 调用中允许编译的 dot 图表数量。 当设置为 1 时，Doxygen\n"
              "将为每个图表单独调用 dot ，这可能会导致显著的进程创建开销， 特别是在具有许多 CPU 核心的系统上。与 DOT_NUM_THREADS\n"
              "一起使用此设置可以优化特定系统的 dot 处理速度。Doxygen 将尝试为每个线程分配均衡的工作量。如果要处理的图表总数超过\n"
              "DOT_NUM_THREADS * DOT_BATCH_SIZE，则会为 dot 创建额外的批次进行处理。\n"
              "最小值：1，最大值：1000，默认值：50。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR 是子图的节点、边和标签的公共属性。当您希望 Doxygen 生成的 dot 文件中的字体外观不同时，可以指定\n"
              "fontname、fontcolor 和 fontsize 属性。有关详细信息，请参阅 <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>节点、边和图属性规范</a> 您需要确保 dot\n"
              "能够找到字体，这可以通过将其放在标准位置或设置 DOTFONTPATH 环境变量或将 DOT_FONTPATH 设置为包含字体的目录来完成。默认\n"
              "graphviz 字体大小为 14。\n"
              "默认值为： fontname=Helvetica,fontsize=10。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR 与 DOT_COMMON_ATTR 连接。对于优雅的样式，您可以添加 'arrowhead=open,\n"
              "arrowtail=open, arrowsize=0.5'。<a\n"
              "href=https://graphviz.org/doc/info/arrows.html>有关箭头形状的完整文档。</a>\n"
              "默认值为： labelfontname=Helvetica,labelfontsize=10。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR 与 DOT_COMMON_ATTR 连接。对于没有节点周围框的视图，设置 'shape=plain' 或\n"
              "'shape=plaintext' <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>形状规范</a>\n"
              "默认值为： shape=box,height=0.2,width=0.4。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_FONTPATH",
              "您可以设置 dot 可以找到在 DOT_COMMON_ATTR 和其他 dot 属性中使用 fontname 指定的字体的路径。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "CLASS_GRAPH",
              "如果 CLASS_GRAPH 标签设置为 YES 或 GRAPH 或 BUILTIN ，Doxygen\n"
              "将为每个已记录的类生成一个图，显示直接和间接继承关系。如果 CLASS_GRAPH 标签设置为 YES 或 GRAPH 且启用了 HAVE_DOT，则将使用\n"
              "dot 绘制图。如果 CLASS_GRAPH 标签设置为 YES 且禁用了 HAVE_DOT，或者如果 CLASS_GRAPH 标签设置为 BUILTIN\n"
              "，则将使用内置生成器。如果 CLASS_GRAPH 标签设置为 TEXT ，直接和间接继承关系将显示为文本/链接。可以通过命令\n"
              "\\inheritancegraph 为特定类显式启用继承图或选择不同的表示形式。可以通过命令 \\hideinheritancegraph 禁用继承图。\n"
              "可能的值有：NO, YES, TEXT, GRAPH和BUILTIN.\n"
              "默认值为： YES。"
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "如果 COLLABORATION_GRAPH 标签设置为 YES ，Doxygen\n"
              "将为每个已记录的类生成一个图，显示该类与其他已记录类之间的直接和间接实现依赖关系（继承、包含和类引用变量）。当 COLLABORATION_GRAPH\n"
              "设置为 NO 时，可以通过命令 \\collaborationgraph 显式启用协作图。可以通过命令 \\hidecollaborationgraph\n"
              "禁用协作图。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "GROUP_GRAPHS",
              "如果 GROUP_GRAPHS 标签设置为 YES ，Doxygen 将为组生成图，显示直接的组依赖关系。当 GROUP_GRAPHS 设置为 NO\n"
              "时，可以通过命令 \\groupgraph 显式启用组依赖图。可以通过命令 \\hidegroupgraph 禁用组图。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "UML_LOOK",
              "如果 UML_LOOK 标签设置为 YES ，Doxygen 将以类似于 OMG 统一建模语言的风格生成继承和协作图。\n"
              "默认值为： NO。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "如果启用了 UML_LOOK 标签，字段和方法将显示在类节点内。如果有很多字段或方法和很多节点，图可能变得太大而无法使用。\n"
              "UML_LIMIT_NUM_FIELDS 阈值限制每种类型的项数，以使大小更易于管理。将此设置为 0 表示无限制。请注意，在强制执行限制之前，阈值可能会超出\n"
              "50%。因此，当您将阈值设置为 10 时，最多可能出现 15 个字段，但如果数量超过 15，则显示的字段总数限制为 10。\n"
              "最小值：0，最大值：100，默认值：10。\n"
              "此标签要求标签 UML_LOOK 设置为YES。"
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "如果启用了 UML_LOOK 标签，字段标签将沿着两个类节点之间的边显示。如果有很多字段和很多节点，图可能变得太杂乱。\n"
              "UML_MAX_EDGE_LABELS 阈值限制项数，以使大小更易于管理。将此设置为 0 表示无限制。\n"
              "最小值：0，最大值：100，默认值：10。\n"
              "此标签要求标签 UML_LOOK 设置为YES。"
          );
  doc->add(
              "DOT_UML_DETAILS",
              "如果 DOT_UML_DETAILS 标签设置为 NO ，Doxygen 将在 UML 图中显示不带类型和参数的属性和方法。如果\n"
              "DOT_UML_DETAILS 标签设置为 YES ，Doxygen 将在 UML 图中为属性和方法添加类型和参数。如果 DOT_UML_DETAILS\n"
              "标签设置为 NONE，Doxygen 将不在 UML 图中生成包含类成员信息的字段。类图看起来类似于默认类图，但使用 UML 表示法表示关系。\n"
              "可能的值有：NO, YES和NONE.\n"
              "默认值为： NO。\n"
              "此标签要求标签 UML_LOOK 设置为YES。"
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "DOT_WRAP_THRESHOLD\n"
              "标签可用于设置在单行上显示的最大字符数。如果实际行长度显著超过此阈值，它将被换行到多行。应用了一些启发式方法以避免难看的换行。\n"
              "最小值：0，最大值：1000，默认值：17。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "如果 TEMPLATE_RELATIONS 标签设置为 YES ，继承和协作图将显示模板与其实例之间的关系。\n"
              "默认值为： NO。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "INCLUDE_GRAPH",
              "如果 INCLUDE_GRAPH 、ENABLE_PREPROCESSING 和 SEARCH_INCLUDES 标签设置为 YES ，Doxygen\n"
              "将为每个已记录的文件生成一个图，显示该文件与其他已记录文件之间的直接和间接包含依赖关系。当 INCLUDE_GRAPH 设置为 NO 时，可以通过命令\n"
              "\\includegraph 显式启用包含图。可以通过命令 \\hideincludegraph 禁用包含图。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "如果 INCLUDED_BY_GRAPH 、ENABLE_PREPROCESSING 和 SEARCH_INCLUDES 标签设置为 YES\n"
              "，Doxygen 将为每个已记录的文件生成一个图，显示该文件与其他已记录文件之间的直接和间接包含依赖关系。当 INCLUDED_BY_GRAPH 设置为\n"
              "NO 时，可以通过命令 \\includedbygraph 显式启用被包含图。可以通过命令 \\hideincludedbygraph 禁用被包含图。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "CALL_GRAPH",
              "如果 CALL_GRAPH 标签设置为 YES ，Doxygen 将为每个全局函数或类方法生成调用依赖图。\n"
              "\n"
              "请注意，启用此选项将显著增加运行时间。因此在大多数情况下，最好只使用 \\callgraph 命令为选定的函数启用调用图。可以通过\n"
              "\\hidecallgraph 命令禁用调用图。\n"
              "默认值为： NO。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "CALLER_GRAPH",
              "如果 CALLER_GRAPH 标签设置为 YES ，Doxygen 将为每个全局函数或类方法生成调用者依赖图。\n"
              "\n"
              "请注意，启用此选项将显著增加运行时间。因此在大多数情况下，最好只使用 \\callergraph 命令为选定的函数启用调用者图。可以通过\n"
              "\\hidecallergraph 命令禁用调用者图。\n"
              "默认值为： NO。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "如果 GRAPHICAL_HIERARCHY 标签设置为 YES ，Doxygen 将以图形方式显示所有类的层次结构，而不是文本形式。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "如果 DIRECTORY_GRAPH 标签设置为 YES ，Doxygen 将以图形方式显示目录对其他目录的依赖关系。依赖关系由目录中文件之间的\n"
              "#include 关系确定。当 DIRECTORY_GRAPH 设置为 NO 时，可以通过命令 \\directorygraph 显式启用目录图。可以通过命令\n"
              "\\hidedirectorygraph 禁用目录图。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "DIR_GRAPH_MAX_DEPTH 标签可用于限制由 dot 在目录依赖图中生成的子目录级别的最大数量。\n"
              "最小值：1，最大值：25，默认值：1。\n"
              "此标签要求标签 DIRECTORY_GRAPH 设置为YES。"
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "DOT_IMAGE_FORMAT 标签可用于设置由 dot 生成的图像的图像格式。有关图像格式的说明，请参阅 dot\n"
              "工具文档中的输出格式部分（Graphviz (see:\n"
              "https://www.graphviz.org/)）。\n"
              "\n"
              "请注意，格式 svg:cairo 和 svg:cairo:cairo 不能与 INTERACTIVE_SVG 结合使用（INTERACTIVE_SVG\n"
              "将设置为 NO）。\n"
              "可能的值有：png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo, png:cairo:gd,\n"
              "png:cairo:cairo, png:cairo:gdiplus, png:gdiplus, png:gdiplus:gdiplus,\n"
              "svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core, gif:cairo, gif:cairo:gd,\n"
              "gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus, gif:gd, gif:gd:gd,\n"
              "jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd, jpg:gd:gd,\n"
              "jpg:gdiplus和jpg:gdiplus:gdiplus.\n"
              "默认值为： png。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "INTERACTIVE_SVG",
              "如果 DOT_IMAGE_FORMAT 设置为 svg 或 svg:svg 或 svg:svg:core，则可以将此选项设置为 YES\n"
              "以启用允许缩放和平移的交互式 SVG 图像的生成。\n"
              "\n"
              "请注意，这需要除 Internet Explorer 之外的现代浏览器。已测试并正常工作的有 Firefox、Chrome、Safari 和 Opera。\n"
              "\n"
              "注意，当 DOT_IMAGE_FORMAT 设置为 svg:cairo 或 svg:cairo:cairo 时，此选项将自动禁用。\n"
              "默认值为： NO。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_PATH",
              "DOT_PATH 标签可用于指定可以找到 dot 工具的路径。如果留空，则假设 dot 工具可以在 path 中找到。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOTFILE_DIRS",
              "DOTFILE_DIRS 标签可用于指定一个或多个包含包含在文档中的 dot 文件的目录（请参阅 \\dotfile 命令）。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DIA_PATH",
              "您可以在 Doxygen 文档中包含使用 dia 制作的图表。Doxygen 随后将运行 dia 生成图表并将其插入文档中。DIA_PATH 标签允许您指定\n"
              "dia 二进制文件所在的目录。如果留空，则假设 dia 可以在默认搜索路径中找到。"
          );
  doc->add(
              "DIAFILE_DIRS",
              "DIAFILE_DIRS 标签可用于指定一个或多个包含包含在文档中的 dia 文件的目录（请参阅 \\diafile 命令）。"
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "使用 PlantUML 时， PLANTUML_JAR_PATH 标签应用于指定 java 可以找到 plantuml.jar 文件的路径或要使用的 jar\n"
              "文件的文件名。如果留空，则假设不使用 PlantUML 或在预处理步骤中调用。在这种情况下，Doxygen 在遇到 \\startuml\n"
              "命令时会生成警告，并且不会为图表生成输出。"
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "使用 PlantUML 时， PLANTUML_CFG_FILE 标签可用于为 PlantUML 指定配置文件。"
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "使用 PlantUML 时，指定的路径用于搜索 PlantUML 块中 !include 语句指定的文件。"
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "PLANTUMLFILE_DIRS 标签可用于指定一个或多个包含包含在文档中的 PlantUml 文件的目录（请参阅 \\plantumlfile 命令）。"
          );
  doc->add(
              "MERMAID_PATH",
              "使用带有 CLI 呈现的 Mermaid 图表时， MERMAID_PATH 标签应用于指定可以找到 mmdc (Mermaid CLI)\n"
              "可执行文件的目录。如果留空，则禁用基于 CLI 的呈现。对于 HTML 输出，默认通过 JavaScript 使用客户端呈现，不需要 mmdc 。对于\n"
              "LaTeX/PDF 输出，需要 mmdc 来预生成图像。当需要 CLI 呈现但 mmdc 不可用时，Doxygen 将生成警告。"
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "使用 Mermaid 图表时， MERMAID_CONFIG_FILE 标签可用于为 Mermaid CLI 工具（ mmdc ）指定 JSON\n"
              "配置文件。此文件可以包含主题设置和其他 Mermaid 配置选项。"
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "MERMAID_RENDER_MODE 标签选择如何呈现 Mermaid 图表。\n"
              "可能的值有：AUTO （HTML使用客户端渲染，LaTeX/PDF和其他格式使用 mmdc 。如果未设置 MERMAID_PATH\n"
              "，非HTML图表将产生警告）, CLI （使用 mmdc 工具预生成图像（需要 Node.js 和mermaid-js/mermaid-\n"
              "cli）。适用于所有输出格式）和CLIENT_SIDE （在HTML输出中嵌入 mermaid.js 进行客户端渲染。不需要 mmdc\n"
              "但仅适用于HTML输出）.\n"
              "默认值为： AUTO。"
          );
  doc->add(
              "MERMAID_JS_URL",
              "MERMAID_JS_URL 标签指定在使用客户端呈现时（ MERMAID_RENDER_MODE 为 CLIENT_SIDE 或 AUTO ）从中加载\n"
              "mermaid.js 的 URL。默认指向 jsDelivr CDN 上最新的 Mermaid v11 版本。\n"
              "\n"
              "默认 CDN URL 在查看生成的文档时需要互联网访问。对于离线使用，请下载 mermaid.esm.min.mjs 并将其设置为相对路径，或使用\n"
              "MERMAID_RENDER_MODE=CLI 代替预生成图像。\n"
              "示例：\n"
              "- 最新 v11（默认）：https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- 固定版本：https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs.\n"
              "- 本地副本：./mermaid.esm.min.mjs（用户必须将文件放在 HTML 输出目录中）i\n"
              "默认值为： https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs。"
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "MERMAIDFILE_DIRS 标签可用于指定一个或多个包含包含在文档中的 Mermaid 文件的目录（请参阅 \\mermaidfile 命令）。"
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "DOT_GRAPH_MAX_NODES 标签可用于设置图中显示的最大节点数。如果图中的节点数变得大于此值，Doxygen\n"
              "将截断图，这通过将节点表示为红色框来可视化。请注意，如果图中根节点的直接子节点数已经大于 DOT_GRAPH_MAX_NODES\n"
              "，则根本不会显示图。另请注意，图的大小可以通过 MAX_DOT_GRAPH_DEPTH 进一步限制。\n"
              "最小值：0，最大值：10000，默认值：50。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "MAX_DOT_GRAPH_DEPTH 标签可用于设置由 dot 生成的图的最大深度。深度值 3 意味着只显示从根通过最多 3\n"
              "条边的路径可达的节点。距离根节点更远的节点将被省略。请注意，将此选项设置为 1 或 2 可能会大大减少大型代码库所需的计算时间。另请注意，图的大小可以通过\n"
              "DOT_GRAPH_MAX_NODES 进一步限制。使用深度 0 表示没有深度限制。\n"
              "最小值：0，最大值：1000，默认值：0。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "GENERATE_LEGEND",
              "如果 GENERATE_LEGEND 标签设置为 YES ，Doxygen 将生成一个图例页面，解释 dot 生成的图中各种框和箭头的含义。\n"
              "注意： 此标签要求未设置 UML_LOOK，即使用 Doxygen 内部继承和协作图的图形表示。\n"
              "默认值为： YES。\n"
              "此标签要求标签 HAVE_DOT 设置为YES。"
          );
  doc->add(
              "DOT_CLEANUP",
              "如果 DOT_CLEANUP 标签设置为 YES ，Doxygen 将删除用于生成各种图的中间文件。\n"
              "\n"
              "注意：此设置不仅用于 dot 文件，还用于 msc 临时文件。\n"
              "默认值为： YES。"
          );
  doc->add(
              "MSCGEN_TOOL",
              "您可以使用 \\msc 命令在 Doxygen 注释中定义消息序列图。如果 MSCGEN_TOOL 标签留空（默认），则 Doxygen 将使用内置版本的\n"
              "mscgen 工具来生成图表。或者， MSCGEN_TOOL 标签也可以指定外部工具的名称。例如，指定 prog 作为值，Doxygen 将调用工具为\n"
              "prog -T <outfile_format> -o <outputfile> <inputfile>。外部工具应支持输出文件格式\n"
              "\"png\"、\"eps\"、\"svg\" 和 \"ismap\"。"
          );
  doc->add(
              "MSCFILE_DIRS",
              "MSCFILE_DIRS 标签可用于指定一个或多个包含包含在文档中的 msc 文件的目录（请参阅 \\mscfile 命令）。"
          );
}
